@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoEnding.cpp,v 1.16 2009/09/12 19:48:08 bowkenken Exp $
+* $Id: DemoEnding.cpp,v 1.19 2010/02/01 08:28:12 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -154,7 +154,7 @@ void DemoEnding::init()
 
 	WSCstring sFontPoint = ENDING_FONT_POINT * 10;
 	WSCstring sFontName = "";
-	sFontName += "-*-*-*-i-normal--*-";
+	sFontName += "-*-*-*-i-normal-*-*-";
 	sFontName += sFontPoint;
 	sFontName += "-*,-*";
 
@@ -203,21 +203,6 @@ void DemoEnding::initAnime()
 	waitTime = 0;
 	frame = 0;
 
-#ifdef D_GTK
-	w = gMapDrawingArea->allocation.width;
-	h = gMapDrawingArea->allocation.height;
-#endif // D_GTK
-
-#ifdef D_MFC
-	CXlnlView *view = theApp.m_pMainFrm->GetView();
-	CRect rect;
-	view->GetClientRect( &rect );
-
-	w = rect.Width();
-	h = rect.Height();
-#endif // D_MFC
-
-	long x_dot, y_dot;
 	if( get_lang_kind() == LANG_KIND_ENGLISH ){
 		x_dot = ENDING_FONT_DOT / 2;
 		y_dot = ENDING_FONT_DOT;
@@ -262,21 +247,10 @@ void DemoEnding::initAnime()
 			k += get_next_char_len( &(gStrEnding[i][k]) );
 		}
 
-		baseX[i] = (w - (j * x_dot)) / 2;
-		baseY[i] = h / 2;
+		baseX[i] = j * x_dot;
 
 		len = max_l( len, j );
 	}
-
-	for( long i = 0; i < EPILOGUE_LINE_MAX_N; i++ ){
-		if( gStrEnding[i] == NULL )
-			break;
-
-		for( long j = 0; j < len; j++ ){
-			mx[i][j] = baseX[i] + (j * x_dot);
-			my[i][j] = baseY[i] + (i * y_dot);
-		}
-	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -404,8 +378,8 @@ bool DemoEnding::drawEpilogue()
 
 	long sx = gPcgDun.getScrollBarX();
 	long sy = gPcgDun.getScrollBarY();
-	long sw = w;
-	long sh = h;
+	long sw = gPcgDun.getScrollBarW();
+	long sh = gPcgDun.getScrollBarH();
 
 	long ww = pcgEpilogue.getWidth();
 	long hh = pcgEpilogue.getHeight();
@@ -449,6 +423,9 @@ void DemoEnding::drawEpilogueStory( long frame )
 	else
 		nDraw = (frame / FRAME_PER_CHAR) - WAIT_FRAME_CHAR;
 
+	long sw = gPcgDun.getScrollBarW();
+	long sh = gPcgDun.getScrollBarH();
+
 	for( long i = 0; i < EPILOGUE_LINE_MAX_N; i++ ){
 		if( gStrEnding[i] == NULL )
 			break;
@@ -463,11 +440,15 @@ void DemoEnding::drawEpilogueStory( long frame )
 			}
 
 			if( n < nDraw ){
-				x[i][j] = mx[i][j];
-				y[i][j] = my[i][j];
+				long bx = (sw - baseX[i]) / 2;
+				long by = sh / 2;
+				long mx = bx + (j * x_dot);
+				long my = by + (i * y_dot);
+				x[i][j] = mx;
+				y[i][j] = my;
 			} else {
-				x[i][j] = w * 2;
-				y[i][j] = h * 2;
+				x[i][j] = sw * 2;
+				y[i][j] = sh * 2;
 			}
 
 			n++;
