@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoSpace.cpp,v 1.17 2009/09/12 22:50:56 bowkenken Exp $
+* $Id: DemoSpace.cpp,v 1.20 2010/02/01 08:28:12 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -43,12 +43,12 @@
 #define STR_ENDING_SPACE_DIR_NAME	"ending/space/"
 #define STR_ENDING_NEBULA_DIR_NAME	"ending/nebula/"
 
-static const long XR = 16384;
-static const long YR = 16384;
-static const long ZR = 256;
-static const long NXR = 1024;
-static const long NYR = 1024;
-static const long NZR = 128;
+static const long XR = 16300;
+static const long YR = 16300;
+static const long ZR = 250;
+static const long NXR = 1020;
+static const long NYR = 1020;
+static const long NZR = 120;
 static const long Z_SPEED = -1;
 
 ////////////////////////////////////////////////////////////////
@@ -201,7 +201,7 @@ void DemoSpace::init()
 
 	WSCstring sFontPoint = SPACE_FONT_POINT * 10;
 	WSCstring sFontName = "";
-	sFontName += "-*-*-*-i-normal--*-";
+	sFontName += "-*-*-*-i-normal-*-*-";
 	sFontName += sFontPoint;
 	sFontName += "-*,-*";
 
@@ -250,9 +250,6 @@ void DemoSpace::init()
 void DemoSpace::initAnime()
 {
 #ifdef D_GTK
-	w = gMapDrawingArea->allocation.width;
-	h = gMapDrawingArea->allocation.height;
-
 	// ơ֥
 
 	for( long i = 0; i < COLOR_TAB_MAX_N; i++ ){
@@ -268,13 +265,6 @@ void DemoSpace::initAnime()
 #endif // D_GTK
 
 #ifdef D_MFC
-	CXlnlView *view = theApp.m_pMainFrm->GetView();
-	CRect rect;
-	view->GetClientRect( &rect );
-
-	w = rect.Width();
-	h = rect.Height();
-
 	// ơ֥
 
 	const UINT txW = 1;
@@ -386,8 +376,8 @@ bool DemoSpace::draw( bool flagDrawStaffRoll )
 
 	long sx = gPcgDun.getScrollBarX();
 	long sy = gPcgDun.getScrollBarY();
-	long sw = w;
-	long sh = h;
+	long sw = gPcgDun.getScrollBarW();
+	long sh = gPcgDun.getScrollBarH();
 
 	if( nRandmSel > -1 ){
 		long ww = pcgSpace.getWidth();
