@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoTitle.cpp,v 1.16 2010/02/01 08:28:12 bowkenken Exp $
+* $Id: DemoTitle.cpp,v 1.19 2010/07/13 08:47:14 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -164,6 +164,18 @@ void DemoTitle::init()
 	gtk_style_set_font( pTitleStyle, gdk_fontset_load( sFontName ) );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	// ǥեȤΥ
+
+	if( pTitleStyle == NULL )
+		pTitleStyle = (void *)1;
+
+	// եȤ
+
+	CGContextRef context = gPcgDun.getWBuf()->getPixMap();
+	CGContextSelectFont( context, "Arial", TITLE_FONT_POINT, kCGEncodingMacRoman );
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	// ǥեȤΥ
 
@@ -216,6 +228,11 @@ void DemoTitle::initAnime()
 	h = gMapDrawingArea->allocation.height;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	w = gMainMapWin.mapScrollView.frame.size.width;
+	h = gMainMapWin.mapScrollView.frame.size.height;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	CXlnlView *view = theApp.m_pMainFrm->GetView();
 	CRect rect;
@@ -259,6 +276,20 @@ bool DemoTitle::draw()
 			gMapDrawingArea->allocation.height );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	CGContextRef context = gPcgDun.getWBuf()->getPixMap();
+	CGRect rect = gMainMapWin.mapScrollView.bounds;
+	rect.origin.y = -rect.origin.y - rect.size.height;
+
+	CGContextSaveGState(context);
+
+	CGContextClipToRect(context, rect);
+	CGContextSetRGBFillColor( context, 0.0f, 0.0f, 0.0f, 1.0f );
+	CGContextFillRect( context, rect );
+
+	CGContextRestoreGState(context);
+#endif // D_IPHONE
+
 	// طʲ
 
 	long x = gPcgDun.getScrollBarX();
@@ -307,6 +338,11 @@ bool DemoTitle::draw()
 
 	frame++;
 
+#ifdef D_IPHONE
+	[gMainMapWin.view setNeedsDisplay];
+	[gMainMapWin.mapView setNeedsDisplay];
+#endif // D_IPHONE
+
 	return true;
 }
 
@@ -734,6 +770,20 @@ void DemoTitle::drawTitleChar(
 	gdk_draw_string( d, font, gc, x, y, str );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	CGContextRef context = gPcgDun.getWBuf()->getPixMap();
+
+	CGContextSaveGState(context);
+
+	CGContextSetRGBFillColor( context, r / 255.0f, g / 255.0f, b / 255.0f, 255 / 255.0f );
+	CGContextSetTextPosition( context, (CGFloat)x, (CGFloat)-y );
+
+	CGContextShowText( context, str, str_len_std( str ) );
+	CGContextDrawPath( context, kCGPathStroke );
+
+	CGContextRestoreGState(context);
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	D3DCOLOR color = D3DCOLOR_XRGB( r, g, b );
 
