@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: FileList.cpp,v 1.24 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: FileList.cpp,v 1.25 2010/08/05 00:08:57 bowkenken Exp $
 ***************************************************************/
 
 #ifdef D_WS
@@ -41,8 +41,10 @@
 #include "draw.h"
 #include "town.h"
 #include "gfile.h"
+#include "play-rep.h"
 #include "draw-prot.h"
 #include "gfile-prot.h"
+#include "play-rep-prot.h"
 
 ////////////////////////////////////////////////////////////////
 // ե븡Υ󥹥ȥ饯
