@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: FileList.h,v 1.26 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: FileList.h,v 1.27 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef FILE_LIST_H
@@ -38,7 +38,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#if defined( D_WS ) || defined( D_GTK )
+#if defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
 # include <dirent.h>
 # include <sys/stat.h>
 #endif
@@ -51,6 +51,10 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_IPHONE
+# include "IPhoneWSCstring.h"
+#endif // D_IPHONE
+
 #ifdef D_MFC
 # include "xlnl-dows/stdafx.h"
 # include "MfcWSCstring.h"
