@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.cpp,v 1.31 2010/01/31 16:59:40 bowkenken Exp $
+* $Id: GameMusic.cpp,v 1.32 2010/02/23 16:48:05 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -43,15 +43,6 @@
 
 ////////////////////////////////////////////////////////////////
 
-#ifdef	HAVE_SDL_SDL_MIXER_H
-static int audioRate = 22050;
-static unsigned short audioFormat = AUDIO_S16;
-static int audioChannels = 2;
-static int audioBuffers = 1024;
-#endif
-
-////////////////////////////////////////////////////////////////
-
 static void donePlayEnding();
 static void donePlayEffect();
 
@@ -65,6 +56,18 @@ GameMusic::GameMusic()
 	music = NULL;
 #endif
 
+#ifdef	HAVE_SDL_SDL_MIXER_H
+	audioRate = 22050;
+	audioFormat = AUDIO_S16;
+	audioChannels = 2;
+	audioBuffers = 1024;
+#else
+	audioRate = 22050;
+	audioFormat = 0;
+	audioChannels = 2;
+	audioBuffers = 1024;
+#endif
+
 	currentKind = MUSIC_KIND_NULL;
 	currentIdx = 0;
 	currentName = "";
@@ -105,6 +108,8 @@ void GameMusic::init()
 	SDL_Init( SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_JOYSTICK );
 #endif
 
+	audioBuffers = (int)g_audio_buf_siz;
+
 #ifdef	HAVE_SDL_SDL_MIXER_H
 	if( Mix_OpenAudio( audioRate, audioFormat, audioChannels,
 			audioBuffers ) ){
