@@ -25,13 +25,14 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.cpp,v 1.29 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GlobalVar.cpp,v 1.34 2010/07/20 18:17:59 bowkenken Exp $
 ***************************************************************/
 
 #include "GlobalVar.h"
 
 SelConf gSelConf;
 
+CuiMouse gCuiMouse;
 GuiMenu gGuiMenu;
 GuiMessage gGuiMessage;
 GuiStat gGuiStat;
@@ -78,6 +79,13 @@ GtkWidget *gMapHScrollBar;
 GtkWidget *gMapVScrollBar;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+NSLock *gMainLock;
+UIWindow *gMainWindow;
+MainNaviCon *gMainNaviCon;
+MainMapWin *gMainMapWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 volatile bool gFlagInitMfcDone;
 bool gFlagExit;
