@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.h,v 1.33 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GlobalVar.h,v 1.39 2010/08/01 06:48:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GLOBAL_VAR_H
@@ -52,7 +52,9 @@ typedef long GtkButton;
 #endif // D_WS
 
 #include "party.h"
+#include "draw.h"
 #include "SelConf.h"
+#include "CuiMouse.h"
 #include "GuiMenu.h"
 #include "GuiMessage.h"
 #include "GuiStat.h"
@@ -73,6 +75,8 @@ typedef long GtkButton;
 #include "Key.h"
 #include "MouseMotion.h"
 
+#include "draw-prot.h"
+
 #ifdef D_WS
 # include "StatWinIdx.h"
 #endif // D_WS
@@ -81,6 +85,11 @@ typedef long GtkButton;
 # include "GuiStat.h"
 #endif // D_GTK
 
+#ifdef D_IPHONE
+# include "main-iphone.h"
+# include "GuiStat.h"
+#endif // D_IPHONE
+
 #ifdef D_MFC
 # include "xlnl-dows/Dir3d.h"
 #endif // D_MFC
@@ -92,6 +101,9 @@ typedef long GtkButton;
 // եå
 extern SelConf gSelConf;
 
+// CUI ޥ
+extern CuiMouse gCuiMouse;
+
 // ˥塼ɥ
 extern GuiMenu gGuiMenu;
 
@@ -174,6 +186,13 @@ extern GtkWidget *gMapVScrollBar;
 extern GuiStat gGuiStat;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+extern NSLock *gMainLock;
+extern UIWindow *gMainWindow;
+extern MainNaviCon *gMainNaviCon;
+extern MainMapWin *gMainMapWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 extern volatile bool gFlagInitMfcDone;
 extern bool gFlagExit;
