@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.27 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.32 2010/09/01 08:39:29 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -2144,10 +2144,24 @@ void GuiChrSheet::DdxToSheet()
 	mChrSheetWin->m_Stat.m_StrName = mbrData->name;
 
 	mChrSheetWin->m_Stat.m_StrNameEdit = mbrData->name;
-	mChrSheetWin->m_Stat.m_StrFace = mbrData->face.mnr;
-	mChrSheetWin->m_Stat.m_StrRace = get_race_str( &(mbrData->race) );
-	mChrSheetWin->m_Stat.m_StrRaceName = mbrData->race.name;
-	mChrSheetWin->m_Stat.m_StrSex = get_sex_name( mbrData->sex.cur );
+	char strFace[8 * 2 + 1];
+	strFace[0] = mbrData->face.mjr;
+	strFace[1] = mbrData->face.mnr;
+	strFace[0] = '\0';
+	mChrSheetWin->m_Stat.m_StrFace = strFace;
+	if( is_mbr( mbrData ) ){
+		mChrSheetWin->m_Stat.m_StrRace
+				= get_race_str( &(mbrData->race) );
+		mChrSheetWin->m_Stat.m_StrRaceName
+				= mbrData->race.name;
+	} else {
+		mChrSheetWin->m_Stat.m_StrRace
+				= get_mnstr_mjr_name( mbrData->face.mjr );
+		mChrSheetWin->m_Stat.m_StrRaceName
+				= get_mnstr_name( mbrData->mnstr_kind );
+	}
+	mChrSheetWin->m_Stat.m_StrSex = get_sex_name(
+			mbrData->mnstr_kind, mbrData->sex.cur );
 
 	//// HP/MP
 
@@ -2262,149 +2276,191 @@ void GuiChrSheet::DdxToSheet()
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_DEAD ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_DEAD;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_DEAD;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_STONE ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_STONE;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_STONE;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_PARALYZE ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_PARALYZE;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_PARALYZE;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_POISON ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_POISON;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_POISON;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_CONFUSION ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_CONFUSION;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_CONFUSION;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_BLIND ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_BLIND;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_BLIND;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_SLEEP ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_SLEEP;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_SLEEP;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_SILENCE ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_SILENCE;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_SILENCE;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_CAUGHT ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_CAUGHT;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_CAUGHT;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_FEAR ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_FEAR;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_FEAR;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_HALLUCINATION ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_HALLUCINATION;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_HALLUCINATION;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_CHARM ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_CHARM;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_CHARM;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_FLY ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_FLY;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_FLY;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_HUNGRY ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_HUNGRY;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_HUNGRY;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_STARVATION ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_STARVATION;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_STARVATION;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_FAINT ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_FAINT;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_FAINT;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_DRUNK ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_DRUNK;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_DRUNK;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_VANISH ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_VANISH;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_VANISH;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_IRON_BODY ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_IRON_BODY;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_IRON_BODY;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_PASSWALL ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_PASSWALL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_PASSWALL;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
 	if( chk_flg( mbrData->stat, FLG_STAT_SENSE_INVISIBLE ) ){
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_SENSE_INVISIBLE;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_SENSE_INVISIBLE;
 	} else {
-		mChrSheetWin->m_Stat.m_StrStat[k] = MSG_MBR_DATA_STAT_NULL;
+		mChrSheetWin->m_Stat.m_StrStat[k]
+				= MSG_MBR_DATA_STAT_NULL;
 	}
 	k++;
 
@@ -2427,8 +2483,12 @@ void GuiChrSheet::DdxToSheet()
 
 	mChrSheetWin->m_Abl.m_StrName = mbrData->name;
 
-	mChrSheetWin->m_Abl.m_StrClass
-			= get_class_tab()[mbrData->class_n].name;
+	if( is_mbr( mbrData ) ){
+		mChrSheetWin->m_Abl.m_StrClass
+				= get_class_tab()[mbrData->class_n].name;
+	} else {
+		mChrSheetWin->m_Abl.m_StrClass = "----";
+	}
 
 	for( long i = 0; i < ABL_KIND_MAX_N; i++ ){
 		abl_kind_t kind = (abl_kind_t)i;
@@ -2473,13 +2533,27 @@ void GuiChrSheet::DdxToSheet()
 
 	////  A
 
-	class_t *tab = get_class_tab();
-	mChrSheetWin->m_SkillA.m_pClassTab = &(tab[mbrData->class_n]);
-	mChrSheetWin->m_SkillA.m_nSkillHead = SKILL_PER_PAGE_MAX_N * 0;
-	mChrSheetWin->m_SkillA.m_StrName = mbrData->name;
-	mChrSheetWin->m_SkillA.m_StrClass = tab[mbrData->class_n].name;
+	if( is_mbr( mbrData ) ){
+		class_t *tab = get_class_tab();
+		mChrSheetWin->m_SkillA.m_pClassTab
+				= &(tab[mbrData->class_n]);
+		mChrSheetWin->m_SkillA.m_nSkillHead
+				= SKILL_PER_PAGE_MAX_N * 0;
+		mChrSheetWin->m_SkillA.m_StrName
+				= mbrData->name;
+		mChrSheetWin->m_SkillA.m_StrClass
+				= tab[mbrData->class_n].name;
+	}
 
 	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
+		if( !is_mbr( mbrData ) ){
+			mChrSheetWin->m_SkillA.m_StrKind[i] = "";
+			mChrSheetWin->m_SkillA.m_StrLev[i] = "";
+			mChrSheetWin->m_SkillA.m_StrExp[i] = "";
+			mChrSheetWin->m_SkillA.m_StrNeedExp[i] = "";
+			continue;
+		}
+
 		long nSlot = (SKILL_PER_PAGE_MAX_N * 0) + i;
 		long nLev = get_skill_lev_from_slot( mbrData, nSlot );
 		long nExp = get_skill_exp_from_slot( mbrData, nSlot );
@@ -2502,12 +2576,27 @@ void GuiChrSheet::DdxToSheet()
 
 	////  B
 
-	mChrSheetWin->m_SkillB.m_pClassTab = &(tab[mbrData->class_n]);
-	mChrSheetWin->m_SkillB.m_nSkillHead = SKILL_PER_PAGE_MAX_N * 1;
-	mChrSheetWin->m_SkillB.m_StrName = mbrData->name;
-	mChrSheetWin->m_SkillB.m_StrClass = tab[mbrData->class_n].name;
+	if( is_mbr( mbrData ) ){
+		class_t *tab = get_class_tab();
+		mChrSheetWin->m_SkillB.m_pClassTab
+				= &(tab[mbrData->class_n]);
+		mChrSheetWin->m_SkillB.m_nSkillHead
+				= SKILL_PER_PAGE_MAX_N * 1;
+		mChrSheetWin->m_SkillB.m_StrName
+				= mbrData->name;
+		mChrSheetWin->m_SkillB.m_StrClass
+				= tab[mbrData->class_n].name;
+	}
 
 	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
+		if( !is_mbr( mbrData ) ){
+			mChrSheetWin->m_SkillB.m_StrKind[i] = "";
+			mChrSheetWin->m_SkillB.m_StrLev[i] = "";
+			mChrSheetWin->m_SkillB.m_StrExp[i] = "";
+			mChrSheetWin->m_SkillB.m_StrNeedExp[i] = "";
+			continue;
+		}
+
 		long nSlot = (SKILL_PER_PAGE_MAX_N * 1) + i;
 		long nLev = get_skill_lev_from_slot( mbrData, nSlot );
 		long nExp = get_skill_exp_from_slot( mbrData, nSlot );
@@ -2538,19 +2627,19 @@ void GuiChrSheet::DdxToSheet()
 		mChrSheetWin->m_Item.m_StrItem[i] = "";
 
 	item_t *item_head = get_mbr_item_asgn( mbrData );
-	if( item_head == NULL )
-		return;
-	item = item_head->next;
+	if( item_head != NULL ){
+		item = item_head->next;
 
-	for( long i = 0; i < MBR_ITEM_MAX_N; i++ ){
-		if( item == NULL )
-			break;
-		if( item == item_head )
-			break;
+		for( long i = 0; i < MBR_ITEM_MAX_N; i++ ){
+			if( item == NULL )
+				break;
+			if( item == item_head )
+				break;
 
-		mChrSheetWin->m_Item.m_StrItem[i] = item->name;
+			mChrSheetWin->m_Item.m_StrItem[i] = item->name;
 
-		item = item->next;
+			item = item->next;
+		}
 	}
 
 	// 
@@ -2561,25 +2650,24 @@ void GuiChrSheet::DdxToSheet()
 		mChrSheetWin->m_Equip.m_StrEquip[i] = "";
 
 	item = get_mbr_item_asgn_equip( mbrData );
-	if( item == NULL )
-		return;
+	if( item != NULL ){
+		const long max_len = 80;
+		char s[80 + 1];
+		char *name;
+		for( long i = 0; i < EQUIP_KIND_MAX_N; i++ ){
+			if( item[i].kind == ITEM_KIND_NULL )
+				name = "";
+			else
+				name = item[i].name;
 
-	const long max_len = 80;
-	char s[80 + 1];
-	char *name;
-	for( long i = 0; i < EQUIP_KIND_MAX_N; i++ ){
-		if( item[i].kind == ITEM_KIND_NULL )
-			name = "";
-		else
-			name = item[i].name;
+			sn_printf( s, max_len, "%-*s: %-*s",
+					(int)get_equip_ttl_max_len(),
+					get_item_equip_name( (equip_kind_t)i ),
+					(int)ITEM_NAME_MAX_LEN,
+					name );
 
-		sn_printf( s, max_len, "%-*s: %-*s",
-				(int)get_equip_ttl_max_len(),
-				get_item_equip_name( (equip_kind_t)i ),
-				(int)ITEM_NAME_MAX_LEN,
-				name );
-
-		mChrSheetWin->m_Equip.m_StrEquip[i] = s;
+			mChrSheetWin->m_Equip.m_StrEquip[i] = s;
+		}
 	}
 
 	// ɽ
@@ -2641,19 +2729,28 @@ void GuiChrSheet::drawStat( mbr_t *org, mbr_t *mbr )
 
 	////
 
-	static char face[1 + 1];
-	face[0] = mbr->face.mnr;
-	face[1] = '\0';
+	static char face[8 * 2 + 1];
+	face[0] = mbr->face.mjr;
+	face[1] = mbr->face.mnr;
+	face[2] = '\0';
 
 	gtk_entry_set_text( GTK_ENTRY( mStatName ), mbr->name );
 	gtk_entry_set_text( GTK_ENTRY( mStatFace ), face );
-	set_label_text_button( GTK_BUTTON( mStatRace ),
-			get_race_str( &(mbr->race) ),
-			0.0, 0.5 );
-	gtk_entry_set_text( GTK_ENTRY( mStatRaceName ),
+	if( is_mbr( mbrData ) ){
+		set_label_text_button( GTK_BUTTON( mStatRace ),
+				get_race_str( &(mbr->race) ),
+				0.0, 0.5 );
+		gtk_entry_set_text( GTK_ENTRY( mStatRaceName ),
 			get_race_name( &(mbr->race) ) );
+	} else {
+		set_label_text_button( GTK_BUTTON( mStatRace ),
+				get_mnstr_mjr_name( mbr->face.mjr ),
+				0.0, 0.5 );
+		gtk_entry_set_text( GTK_ENTRY( mStatRaceName ),
+				get_mnstr_name( mbrData->mnstr_kind ) );
+	}
 	set_label_text_button( GTK_BUTTON( mStatSex ),
-			get_sex_name( mbr->sex.cur ),
+			get_sex_name( mbr->mnstr_kind, mbr->sex.cur ),
 			0.0, 0.5 );
 
 	//// HP/MP
@@ -3053,11 +3150,18 @@ void GuiChrSheet::drawAbl( mbr_t *org, mbr_t *mbr )
 		return;
 
 #ifdef D_GTK
-	class_t *class_tab = get_class_tab();
-	if( class_tab != NULL ){
+	if( is_mbr( mbr ) ){
+		class_t *class_tab = get_class_tab();
+		if( class_tab != NULL ){
+			set_label_text_button(
+					GTK_BUTTON( mAblClass ),
+					class_tab[mbr->class_n].name,
+					0.5, 0.5 );
+		}
+	} else {
 		set_label_text_button(
 				GTK_BUTTON( mAblClass ),
-				class_tab[mbr->class_n].name,
+				"----",
 				0.5, 0.5 );
 	}
 
@@ -3165,17 +3269,24 @@ void GuiChrSheet::drawSkill( mbr_t *org, mbr_t *mbr, long page )
 	class_t *class_tab = get_class_tab();
 	if( class_tab == NULL )
 		return;
-
-	set_label_text_button(
-			GTK_BUTTON( mSkillClass ),
-			class_tab[mbr->class_n].name,
-			0.5, 0.5 );
+	if( is_mbr( mbr ) ){
+		set_label_text_button(
+				GTK_BUTTON( mSkillClass ),
+				class_tab[mbr->class_n].name,
+				0.5, 0.5 );
+	} else {
+		set_label_text_button(
+				GTK_BUTTON( mSkillClass ),
+				"----",
+				0.5, 0.5 );
+	}
 
 	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
 		long nSlot = page * SKILL_PER_PAGE_MAX_N + i;
 
-		skill_kind_t skill_kind
-				= class_tab[mbr->class_n].skill[nSlot];
+		skill_kind_t skill_kind = SKILL_KIND_NULL;
+		if( is_mbr( mbr ) )
+			skill_kind = class_tab[mbr->class_n].skill[nSlot];
 		abl_kind_t abl_kind = (abl_kind_t)
 				(ABL_KIND_MAX_N + skill_kind);
 		long mbr_lev = 0;
@@ -3253,7 +3364,9 @@ void GuiChrSheet::drawSkillHint( long nSlot )
 
 	// ƥȤɲ
 
-	skill_kind_t skill_kind = class_tab[mbrData->class_n].skill[nSlot];
+	skill_kind_t skill_kind = SKILL_KIND_NULL;
+	if( is_mbr( mbrData ) )
+		skill_kind = class_tab[mbrData->class_n].skill[nSlot];
 	if( skill_kind == SKILL_KIND_NULL )
 		return;
 
@@ -3281,8 +3394,13 @@ void GuiChrSheet::drawItem( mbr_t *org, mbr_t *mbr )
 
 #ifdef D_GTK
 	item_t *item_head = get_mbr_item_asgn( mbr );
-	if( item_head == NULL )
+	if( item_head == NULL ){
+		for( long i = 0; i < MBR_ITEM_MAX_N; i++ )
+			gtk_label_set_text( GTK_LABEL( mItemName[i] ), "" );
+
 		return;
+	}
+
 	item_t *item = item_head->next;
 
 	long i;
@@ -3318,8 +3436,12 @@ void GuiChrSheet::drawEquip( mbr_t *org, mbr_t *mbr )
 
 #ifdef D_GTK
 	item_t *item = get_mbr_item_asgn_equip( mbr );
-	if( item == NULL )
+	if( item == NULL ){
+		for( long i = 0; i < EQUIP_KIND_MAX_N; i++ )
+			gtk_label_set_text( GTK_LABEL( mEquipName[i] ), "" );
+
 		return;
+	}
 
 	for( long i = 0; i < EQUIP_KIND_MAX_N; i++ ){
 		if( item[i].kind == ITEM_KIND_NULL ){
@@ -3426,14 +3548,22 @@ bool GuiChrSheet::faceChanged()
 
 #ifdef D_GTK
 	const gchar *sg = gtk_entry_get_text( GTK_ENTRY( mStatFace ) );
-	if( sg != NULL )
-		mbrData->face.mnr = sg[0];
+	if( (sg != NULL) && (sg[0] != '\0') ){
+		if( sg[1] == '\0' )
+			mbrData->face.mnr = sg[0];
+		else
+			mbrData->face.mnr = sg[1];
+	}
 #endif // D_GTK
 
 #ifdef	D_MFC
 	const char *sm = mChrSheetWin->m_Stat.m_StrFace;
-	if( sm != NULL )
-		mbrData->face.mnr = sm[0];
+	if( (sm != NULL) && (sm[0] != '\0') ){
+		if( sm[1] == '\0' )
+			mbrData->face.mnr = sm[0];
+		else
+			mbrData->face.mnr = sm[1];
+	}
 #endif //D_MFC
 
 	return true;
