@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.h,v 1.15 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiChrSheet.h,v 1.16 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_CHR_SHEET_H
@@ -123,6 +123,11 @@ public:
 	GtkWidget *mChrSheetWin;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	void *mChrSheetWin;
+#endif // D_IPHONE
+	
 #ifdef D_MFC
 	class CChrSheetSheet *mChrSheetWin;
 #endif // D_MFC
