@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiLastBoss.cpp,v 1.20 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiLastBoss.cpp,v 1.21 2010/06/26 02:38:01 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -827,7 +827,7 @@ bool GuiLastBoss::drawXxAttackAcid(
 	long w = pcgXxAcid.getWidth();
 	long h = pcgXxAcid.getHeight();
 
-	double fix = XX_ACID_HOMING_FIX_POINT;
+	long fix = XX_ACID_HOMING_FIX_POINT;
 
 	for( long m = 0; m < MBR_MAX_N; m++ ){
 		for( long n = XX_ACID_IMAGE_MAX_N - 1; n >= 0; n-- ){
