@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.47 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.50 2010/07/26 08:04:08 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -227,17 +227,11 @@ void GuiMenu::newWin()
 	GtkWidget *handleBox = gtk_handle_box_new();
 	gtk_widget_show( handleBox );
 
-#if 0
-//@@@
-	GtkWidget *toolBar = gtk_toolbar_new( GTK_ORIENTATION_HORIZONTAL,
-			GTK_TOOLBAR_ICONS );
-#else
 	GtkWidget *toolBar = gtk_toolbar_new();
 	gtk_toolbar_set_orientation( GTK_TOOLBAR( toolBar ),
 			GTK_ORIENTATION_HORIZONTAL );
 	gtk_toolbar_set_style( GTK_TOOLBAR( toolBar ),
 			GTK_TOOLBAR_ICONS );
-#endif //@@@
 	gtk_widget_show( toolBar );
 
 	gtk_container_add( GTK_CONTAINER( handleBox ), toolBar );
@@ -318,13 +312,6 @@ void GuiMenu::newWin()
 	// ˥塼ܥؤΥ٥ȡϥɥ
 
 	for( long i = 0; i < MENU_MAX_N_PER_PAGE; i++ ){
-#if 0
-//@@@
-		gtk_signal_connect( GTK_OBJECT( aBtnMenu[i] ),
-			"clicked",
-			GTK_SIGNAL_FUNC( handle_menu_button_clicked ),
-			(gpointer)i );
-#endif
 		gtk_signal_connect( GTK_OBJECT( aBtnMenu[i] ),
 			"button_press_event",
 			GTK_SIGNAL_FUNC( handle_menu_button_press ),
@@ -953,12 +940,9 @@ gint handle_menu_win_delete(
 	GtkWidget *widget, gpointer data
 )
 {
-	if( data == NULL )
-		return 0;
+	gKey.setChar( '0' );
 
-	((GuiMenu *)data)->wipe();
-
-	return 0;
+	return 1;
 }
 #endif // D_GTK
 
