@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.h,v 1.24 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiMenu.h,v 1.25 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MENU_H
@@ -86,6 +86,11 @@ private:
 	GtkWidget *labelMenuPageN;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	void *aBtnMenu[MENU_MAX_N_PER_PAGE];
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	CButton *aBtnMenu[MENU_MAX_N_PER_PAGE + 1];
 #endif // D_WS
@@ -103,6 +108,11 @@ public:
 	gboolean bFlagEnter;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	void *mMenuWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	CMenuWnd *mMenuWin;
 #endif // D_WS
