@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.h,v 1.24 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiMessage.h,v 1.25 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MESSAGE_H
@@ -40,6 +40,10 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_IPHONE
+# include "IPhoneWSCstring.h"
+#endif // D_IPHONE
+
 #ifdef D_MFC
 # include "MfcWSCstring.h"
 #endif // D_MFC
@@ -87,6 +91,11 @@ public:
 	GtkWidget *mMessageWin;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	void *mMessageWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	class CMessageWnd *mMessageWin;
 #endif // D_MFC
