@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.29 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.31 2010/07/18 07:12:42 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -47,19 +47,27 @@
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_delete( GtkWidget *widget, gpointer user_data );
-gint handle_num_destroy( GtkWidget *widget, gpointer user_data );
+gint handle_num_delete( GtkWidget *widget, gpointer data );
+gint handle_num_destroy( GtkWidget *widget, gpointer data );
 gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event );
 
-gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data );
+gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer data );
 
-gint handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data );
+gint handle_num_spin_changed( GtkAdjustment *adj, gpointer data );
 
-gint handle_num_0_clicked( GtkButton *button, gpointer user_data );
-gint handle_num_up_clicked( GtkButton *button, gpointer user_data );
-gint handle_num_down_clicked( GtkButton *button, gpointer user_data );
+gint handle_num_0_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+);
+gint handle_num_up_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+);
+gint handle_num_down_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+);
 
-gint handle_num_ok_clicked( GtkButton *button, gpointer user_data );
+gint handle_num_ok_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+);
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -295,17 +303,17 @@ void GuiNum::newWin()
 			n = i;
 
 		gtk_signal_connect( GTK_OBJECT( mButtonLabel[i] ),
-				"clicked",
+				"button_release_event",
 				GTK_SIGNAL_FUNC( handle_num_0_clicked ),
 				(gpointer)n );
 
 		gtk_signal_connect( GTK_OBJECT( mButtonUp[i] ),
-				"clicked",
+				"button_release_event",
 				GTK_SIGNAL_FUNC( handle_num_up_clicked ),
 				(gpointer)n );
 
 		gtk_signal_connect( GTK_OBJECT( mButtonDown[i] ),
-				"clicked",
+				"button_release_event",
 				GTK_SIGNAL_FUNC( handle_num_down_clicked ),
 				(gpointer)n );
 
@@ -371,19 +379,19 @@ void GuiNum::newWin()
 	// ǾܥؤΥ٥ȡϥɥ
 
 	gtk_signal_connect( GTK_OBJECT( mButtonMin ),
-			"clicked",
+			"button_release_event",
 			GTK_SIGNAL_FUNC( handle_num_ok_clicked ),
 			(gpointer)MENU_NUM_MIN );
 	gtk_signal_connect( GTK_OBJECT( mButtonClear ),
-			"clicked",
+			"button_release_event",
 			GTK_SIGNAL_FUNC( handle_num_ok_clicked ),
 			(gpointer)MENU_NUM_CLR );
 	gtk_signal_connect( GTK_OBJECT( mButtonMax ),
-			"clicked",
+			"button_release_event",
 			GTK_SIGNAL_FUNC( handle_num_ok_clicked ),
 			(gpointer)MENU_NUM_MAX );
 	gtk_signal_connect( GTK_OBJECT( mButtonOk ),
-			"clicked",
+			"button_release_event",
 			GTK_SIGNAL_FUNC( handle_num_ok_clicked ),
 			(gpointer)MENU_NUM_OK );
 
@@ -601,6 +609,11 @@ void GuiNum::up_down_num_label( long n, long d )
 	gtk_label_get( lbl, &str );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	char *str = NULL;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	char str[4 + 1];
 
@@ -906,7 +919,7 @@ void GuiNum::okClicked( menu_num_t n )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_delete( GtkWidget *widget, gpointer user_data )
+gint handle_num_delete( GtkWidget *widget, gpointer data )
 {
 	gKey.setChar( '0' );
 	gGuiNum.wipe();
@@ -920,7 +933,7 @@ gint handle_num_delete( GtkWidget *widget, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_destroy( GtkWidget *widget, gpointer user_data )
+gint handle_num_destroy( GtkWidget *widget, gpointer data )
 {
 	gGuiNum.wipe();
 	gGuiNum.destroy();
@@ -948,11 +961,11 @@ gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event )
 ////////////////////////////////////////////////////////////////
 // ʿĴѲΥϥɥ
 // GtkAdjustment *adj : ʿ
-// gpointer user_data : ߡ
+// gpointer data : ߡ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
+gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer data )
 {
 	if( adj == NULL )
 		return 0;
@@ -966,11 +979,11 @@ gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 // ԥ󡦥ܥĴѲΥϥɥ
 // GtkAdjustment *adj : ʿ
-// gpointer user_data : ߡ
+// gpointer data : ߡ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data )
+gint handle_num_spin_changed( GtkAdjustment *adj, gpointer data )
 {
 	if( adj == NULL )
 		return 0;
@@ -984,13 +997,19 @@ gint handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 // ꥢܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ܥֹ
+// gpointer data : ܥֹ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_0_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_0_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+)
 {
-	gGuiNum.up_down_num_label( (long)user_data, +-0 );
+	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
+		gGuiNum.up_down_num_label( (long)data, +-0 );
+	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
+		gKey.setChar( '0' );
+	}
 
 	return 0;
 }
@@ -999,13 +1018,19 @@ gint handle_num_0_clicked( GtkButton *button, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 // ܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ܥֹ
+// gpointer data : ܥֹ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_up_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_up_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+)
 {
-	gGuiNum.up_down_num_label( (long)user_data, +1 );
+	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
+		gGuiNum.up_down_num_label( (long)data, +1 );
+	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
+		gKey.setChar( '0' );
+	}
 
 	return 0;
 }
@@ -1014,13 +1039,19 @@ gint handle_num_up_clicked( GtkButton *button, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 // ܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ܥֹ
+// gpointer data : ܥֹ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_down_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_down_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+)
 {
-	gGuiNum.up_down_num_label( (long)user_data, -1 );
+	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
+		gGuiNum.up_down_num_label( (long)data, -1 );
+	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
+		gKey.setChar( '0' );
+	}
 
 	return 0;
 }
@@ -1029,13 +1060,19 @@ gint handle_num_down_clicked( GtkButton *button, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 // ǾܥΥåΥϥɥ
 // GtkButton *button : ܥ
-// gpointer user_data : ܥμ
+// gpointer data : ܥμ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-gint handle_num_ok_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_ok_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+)
 {
-	gGuiNum.okClicked( (menu_num_t)(int)user_data );
+	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
+		gGuiNum.okClicked( (menu_num_t)(int)data );
+	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
+		gKey.setChar( '0' );
+	}
 
 	return 0;
 }
