@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.h,v 1.18 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiNum.h,v 1.19 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_NUM_H
@@ -85,6 +85,11 @@ public:
 	GtkWidget *mNumWin;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	void *mNumWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	class CInputNumDlg *mNumWin;
 #endif // D_MFC
