@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.31 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.33 2010/08/01 07:55:18 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -66,6 +66,9 @@ gint handle_stat_name_clicked(
 gint handle_stat_stat_clicked(
 	GtkWidget *widget, gpointer data
 );
+gint handle_stat_mode_clicked(
+	GtkWidget *widget, gpointer data
+);
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -118,6 +121,7 @@ void GuiStat::newWin()
 
 	mStrPreDunLev[0] = '\0';
 	mStrPreTime[0] = '\0';
+	mPreMode = STAT_MODE_MBR;
 
 #ifdef D_GTK
 	// ơɥκ
@@ -196,6 +200,17 @@ void GuiStat::newWin()
 	gtk_box_pack_start( GTK_BOX( vBoxMisc ),
 			labelTime, FALSE, FALSE, 0 );
 	gtk_widget_show( labelTime );
+
+	// ⡼ڤ괹
+
+	btnMode = gtk_button_new_with_label( MSG_STAT_MODE_MBR );
+	gtk_signal_connect( GTK_OBJECT( btnMode ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_stat_mode_clicked ),
+			NULL );
+	gtk_box_pack_start( GTK_BOX( vBoxMisc ),
+			btnMode, FALSE, FALSE, 0 );
+	gtk_widget_show( btnMode );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -376,8 +391,10 @@ void GuiStat::destroy()
 
 	gtk_widget_destroy( labelDunLev );
 	gtk_widget_destroy( labelTime );
+	gtk_widget_destroy( btnMode );
 	labelDunLev = NULL;
 	labelTime = NULL;
+	btnMode = NULL;
 
 	gtk_widget_destroy( vBox );
 
@@ -397,8 +414,18 @@ void GuiStat::destroy()
 
 void GuiStat::redraw( bool flagAdj, bool flagExpose )
 {
-	for( long i = 0; i < MBR_MAX_N; i++ )
-		draw( i, flagExpose );
+	switch( get_stat_mode() ){
+	case STAT_MODE_MAX_N:
+	case STAT_MODE_MBR:
+		for( long i = 0; i < MBR_MAX_N; i++ )
+			draw( i, flagExpose );
+		break;
+	case STAT_MODE_PET:
+		for( long i = 0; i < PET_MAX_N; i++ )
+			draw( MBR_MAX_N + i, flagExpose );
+		break;
+	}
+
 	drawMisc();
 
 	gWinPos[WIN_KIND_STAT].get( WIN_KIND_STAT,
@@ -430,7 +457,34 @@ void GuiStat::draw( long n, bool flagExpose )
 	newWin();
 
 	party_t *pty = get_party();
-	mbr_t *mbr = pty->mbr[n];
+	pet_t **pty_pet = get_party_pet();
+	mbr_t *mbr = NULL;
+	if( n < 0 ){
+		return;
+	} else if( n < MBR_MAX_N ){
+		mbr = pty->mbr[n];
+	} else if( n < (MBR_MAX_N + PET_MAX_N) ){
+		n -= MBR_MAX_N;
+		mbr = pty_pet[n];
+	} else {
+		return;
+	}
+
+	/* Сå */
+
+	if( mbr != NULL ){
+		switch( get_stat_mode() ){
+		case STAT_MODE_MAX_N:
+		case STAT_MODE_MBR:
+			if( !is_mbr( mbr ) )
+				return;
+			break;
+		case STAT_MODE_PET:
+			if( !is_pet( mbr ) )
+				return;
+			break;
+		}
+	}
 
 	WSCstring sName, sAct, sStat, sHp, sMp;
 	long nHp, nMp, nMaxHp, nMaxMp;
@@ -524,6 +578,7 @@ void GuiStat::drawMisc()
 	long maxLen = 40;
 	const char *sDunLev = get_stat_dun_lev_str();
 	const char *sTime = get_stat_time_str();
+	stat_mode_t nMode = (stat_mode_t)get_stat_mode();
 
 #ifdef D_GTK
 	if( strcmp( sDunLev, mStrPreDunLev ) != 0 ){
@@ -544,8 +599,28 @@ void GuiStat::drawMisc()
 		str_nz_cpy( mStrPreTime, sTime, maxLen );
 	}
 
+	if( nMode != mPreMode ){
+		const char *sMode = "----";
+
+		switch( get_stat_mode() ){
+		case STAT_MODE_MAX_N:
+		case STAT_MODE_MBR:
+			sMode = MSG_STAT_MODE_MBR;
+			break;
+		case STAT_MODE_PET:
+			sMode = MSG_STAT_MODE_PET;
+			break;
+		}
+
+		set_label_text_button( GTK_BUTTON( btnMode ),
+				sMode, 0.5, 0.5 );
+
+		mPreMode = nMode;
+	}
+
 	gtk_widget_show( labelDunLev );
 	gtk_widget_show( labelTime );
+	gtk_widget_show( btnMode );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -1062,6 +1137,14 @@ gint handle_stat_name_clicked(
 )
 {
 	long n = (long)data;
+	switch( get_stat_mode() ){
+	case STAT_MODE_MAX_N:
+	case STAT_MODE_MBR:
+		break;
+	case STAT_MODE_PET:
+		n += MBR_MAX_N;
+		break;
+	}
 
 	char sCmdMbr[15 + 1];
 	sCmdMbr[0] = 'A' + n;
@@ -1070,16 +1153,20 @@ gint handle_stat_name_clicked(
 	WSCstring sCmd = "";
 
 	// ˥塼򳫤ƤĤ
+
 	sCmd = "00000000000000000000";
 
 	// Сΰ֤˥ư
+
 	sCmd += ":/misc/cursor/cursor/move member\n";
 	sCmd += sCmdMbr;
 
 	// ˥塼򳫤
+
 	sCmd += "^M";
 
 	// ޥɤ
+
 	set_key_buf_str_tail( sCmd );
 	set_flg_break_key( TRUE );
 
@@ -1099,6 +1186,14 @@ gint handle_stat_stat_clicked(
 )
 {
 	long n = (long)data;
+	switch( get_stat_mode() ){
+	case STAT_MODE_MAX_N:
+	case STAT_MODE_MBR:
+		break;
+	case STAT_MODE_PET:
+		n += MBR_MAX_N;
+		break;
+	}
 
 	char sCmdMbr[15 + 1];
 	sCmdMbr[0] = 'A' + n;
@@ -1107,17 +1202,50 @@ gint handle_stat_stat_clicked(
 	WSCstring sCmd = "";
 
 	// ˥塼򳫤ƤĤ
+
 	sCmd = "00000000000000000000";
 
 	// Сΰ֤˥ư
+
 	sCmd += ":/misc/cursor/cursor/move member\n";
 	sCmd += sCmdMbr;
 
 	// 饯Ȥɽ
-	// sCmd += ":/misc/info/char data\n";
-	sCmd += "C";
+
+	sCmd += ":/misc/info/char data\n";
 
 	// ޥɤ
+
+	set_key_buf_str_tail( sCmd );
+	set_flg_break_key( TRUE );
+
+	return 0;
+}
+#endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// ⡼ڤ괹ܥκå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_stat_mode_clicked(
+	GtkWidget *widget, gpointer data
+)
+{
+	WSCstring sCmd = "";
+
+	// ˥塼򳫤ƤĤ
+
+	sCmd = "00000000000000000000";
+
+	// ⡼ɤڤ괹
+
+	sCmd += ":/misc/info/switch status mode\n";
+
+	// ޥɤ
+
 	set_key_buf_str_tail( sCmd );
 	set_flg_break_key( TRUE );
 
