@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.h,v 1.15 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiStat.h,v 1.17 2010/08/01 06:48:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_STAT_H
@@ -41,6 +41,10 @@
 # include "party.h"
 #endif // D_GTK
 
+#ifdef D_IPHONE
+# include "IPhoneWSCstring.h"
+#endif // D_IPHONE
+
 #ifdef D_MFC
 # include "MfcWSCstring.h"
 #endif // D_MFC
@@ -54,6 +58,7 @@ private:
 
 	char mStrPreDunLev[40 + 1];
 	char mStrPreTime[40 + 1];
+	stat_mode_t mPreMode;
 
 #ifdef D_GTK
 	GtkWidget *vBox;
@@ -72,6 +77,7 @@ private:
 	GtkWidget *vBoxMisc;
 	GtkWidget *labelDunLev;
 	GtkWidget *labelTime;
+	GtkWidget *btnMode;
 
 	GdkGC *mFgGcHp[MBR_MAX_N];
 	GdkGC *mFgGcMp[MBR_MAX_N];
@@ -94,6 +100,11 @@ public:
 	GtkWidget *mStatWin;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+//@@@
+	void *mStatWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	CStatWnd *mStatWin;
 #endif // D_MFC
