@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiWords.h,v 1.6 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GuiWords.h,v 1.7 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_WORDS_H
@@ -63,6 +63,10 @@ public:
 	GtkWidget *mWordsWin;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	void *mWordsWin;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	class CWordsDlg *mWordsWin;
 #endif // D_MFC
