@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.28 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: Key.cpp,v 1.30 2010/07/20 22:53:24 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -770,7 +770,7 @@ bool Key::chkBuf()
 
 bool Key::moveCrsrRel( long mapX, long mapY )
 {
-	pos_t *crsr = get_crsr();
+	pos_t *crsr = get_main_crsr();
 	if( crsr == NULL )
 		return false;
 
@@ -789,12 +789,19 @@ bool Key::moveCrsrRel( long mapX, long mapY )
 
 bool Key::moveCrsrAbs( long mapX, long mapY )
 {
-	if( !g_flg_gui )
-		return true;
 	if( get_flg_play_replay() )
 		return true;
 
-	pos_t *crsr = get_crsr();
+#if	0
+//@@@
+	char buf[63 + 1];
+	sn_printf( buf, 63, "%%X%ldY%ld;", mapX, mapY );
+	setString( buf, false, false );
+
+	return true;
+#endif
+
+	pos_t *crsr = get_main_crsr();
 	if( crsr == NULL )
 		return false;
 
@@ -808,7 +815,7 @@ bool Key::moveCrsrAbs( long mapX, long mapY )
 
 	crsr->x = mapX;
 	crsr->y = mapY;
-	CheckMoveCrsr();
+	checkMoveCrsr();
 	setString( "|", false, true );
 
 	return true;
@@ -818,14 +825,14 @@ bool Key::moveCrsrAbs( long mapX, long mapY )
 // 뤬ư˥ޥåפ򥹥뤹
 ////////////////////////////////////////////////////////////////
 
-void Key::CheckMoveCrsr()
+void Key::checkMoveCrsr()
 {
 	long a = 1;
 #ifdef	D_MFC
 	a = 0;
 #endif	// D_MFC
 
-	pos_t *crsr = get_crsr();
+	pos_t *crsr = get_main_crsr();
 	if( crsr == NULL )
 		return;
 
@@ -876,8 +883,6 @@ bool Key::scrollRel( long mapX, long mapY )
 
 bool Key::scrollAbs( long mapX, long mapY )
 {
-	if( !g_flg_gui )
-		return true;
 	if( get_flg_play_replay() )
 		return true;
 
@@ -895,7 +900,7 @@ bool Key::scrollAbs( long mapX, long mapY )
 
 	draw_gui->x = mapX;
 	draw_gui->y = mapY;
-	CheckScroll();
+	checkScroll();
 	setString( "|", false, true );
 
 	return true;
@@ -905,23 +910,27 @@ bool Key::scrollAbs( long mapX, long mapY )
 // ޥåפ뤷˥ΤϤ߽Фå
 ////////////////////////////////////////////////////////////////
 
-void Key::CheckScroll()
+void Key::checkScroll()
 {
-	pos_t *crsr = get_crsr();
+	pos_t *crsr = get_main_crsr();
 	if( crsr == NULL )
 		return;
 
+	long x = gPcgDun.getScrollBarX();
+	long y = gPcgDun.getScrollBarY();
 	long w = gPcgDun.getScrollBarW();
 	long h = gPcgDun.getScrollBarH();
+	x /= gPcgDun.getTileSizeX( true );
+	y /= gPcgDun.getTileSizeY( true );
 	w /= gPcgDun.getTileSizeX( true );
 	h /= gPcgDun.getTileSizeY( true );
 
-	if( crsr->x < crsr->x )
-		crsr->x = crsr->x;
-	if( crsr->y < crsr->y )
-		crsr->y = crsr->y;
-	if( crsr->x > (crsr->x + w - 1) )
-		crsr->x = (crsr->x + w - 1);
-	if( crsr->y > (crsr->y + h - 1) )
-		crsr->y = (crsr->y + h - 1);
+	if( crsr->x < x )
+		crsr->x = x;
+	if( crsr->y < y )
+		crsr->y = y;
+	if( crsr->x > (x + w - 1) )
+		crsr->x = (x + w - 1);
+	if( crsr->y > (y + h - 1) )
+		crsr->y = (y + h - 1);
 }
