@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.h,v 1.16 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: Key.h,v 1.18 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef KEY_H
@@ -44,6 +44,11 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_IPHONE
+# include "IPhoneMisc.h"
+# include "IPhoneWSCstring.h"
+#endif // D_IPHONE
+
 #ifdef D_MFC
 # include "MfcWSCstring.h"
 #endif // D_MFC
@@ -81,10 +86,10 @@ public:
 
 	bool moveCrsrRel( long mapX, long mapY );
 	bool moveCrsrAbs( long mapX, long mapY );
-	void CheckMoveCrsr();
+	void checkMoveCrsr();
 	bool scrollRel( long mapX, long mapY );
 	bool scrollAbs( long mapX, long mapY );
-	void CheckScroll();
+	void checkScroll();
 
 #ifdef D_MFC
 	void handleKeyDown(
