@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.43 2010/05/10 15:31:55 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.45 2010/08/01 18:51:53 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -241,8 +241,10 @@ void funcMotionPoint(
 	// ޥåסΰư
 
 #ifdef D_MFC
-	nCurX = nCurX * _100_PERCENT / g_Dir3d.nTileSizeRate;
-	nCurY = nCurY * _100_PERCENT / g_Dir3d.nTileSizeRate;
+	if( g_flg_gui ){
+		nCurX = nCurX * _100_PERCENT / g_Dir3d.nTileSizeRate;
+		nCurY = nCurY * _100_PERCENT / g_Dir3d.nTileSizeRate;
+	}
 #endif // D_MFC
 
 	long x = gPcgDun.getScrollBarX();
@@ -273,7 +275,8 @@ void funcMotionPoint(
 
 	// ơС˥ҥȤɽ
 
-	guiMapPrintStatBarHint();
+	if( g_flg_gui )
+		guiMapPrintStatBarHint();
 }
 
 ////////////////////////////////////////////////////////////////
@@ -296,8 +299,10 @@ void funcMotionDragL(
 	long dx = nCurX - nBgnX;
 	long dy = nCurY - nBgnY;
 #ifdef D_MFC
-	dx = dx * _100_PERCENT / g_Dir3d.nTileSizeRate;
-	dy = dy * _100_PERCENT / g_Dir3d.nTileSizeRate;
+	if( g_flg_gui ){
+		dx = dx * _100_PERCENT / g_Dir3d.nTileSizeRate;
+		dy = dy * _100_PERCENT / g_Dir3d.nTileSizeRate;
+	}
 #endif // D_MFC
 	long x = gMapDragBgnX - dx;
 	long y = gMapDragBgnY - dy;
@@ -723,7 +728,7 @@ void funcMotionScroll(
 		}
 	}
 
-	gKey.setString( "|" );
+	gKey.setChar( CMD_KEY_IDLE );
 #else
 		switch( dir ){
 		case MouseMotion::nScrollLeft:
