@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.cpp,v 1.28 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: Pcg.cpp,v 1.31 2010/08/05 00:08:57 bowkenken Exp $
 ***************************************************************/
 
 #include <time.h>
@@ -44,10 +44,12 @@
 #include "amenu.h"
 #include "spell.h"
 #include "gfile.h"
+#include "play-rep.h"
 #include "gmain-prot.h"
 #include "misc-prot.h"
 #include "draw-prot.h"
 #include "gfile-prot.h"
+#include "play-rep-prot.h"
 
 #include "Pcg.h"
 #include "GlobalVar.h"
@@ -126,6 +128,48 @@ void Pcg::load( WSCstring path )
 	} while( 0 );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	NSString *pathStr = [NSString stringWithUTF8String:(const char *)path];
+	UIImage *tmpUIImg = [[UIImage alloc] initWithContentsOfFile:pathStr];
+	CGImageRef tmpCGImg = tmpUIImg.CGImage;
+
+	UIImage *buf = tmpUIImg;
+
+	// Ѥοȴˤ
+
+	WSCstring ext = FileList::getExt( path );
+	do {
+		if( (ext != "bmp") && (ext != "BMP") )
+			break;
+
+		CGColorSpaceRef colorSpace = CGColorSpaceCreateDeviceRGB();
+
+		long w = CGImageGetWidth(tmpCGImg);
+		long h = CGImageGetHeight(tmpCGImg);
+		unsigned char *frameBuf = (unsigned char*)malloc(w * h * 4);
+
+		CGContextRef tmpContext = CGBitmapContextCreate(frameBuf, w, h, 8, w * 4, colorSpace, kCGImageAlphaPremultipliedLast);
+		CGContextDrawImage(tmpContext, CGRectMake(0, 0, w, h), tmpCGImg);
+		CGContextRelease(tmpContext);
+
+		CGColorSpaceRelease(colorSpace);
+
+		CGFloat compo[4];
+		compo[0] = (CGFloat)(frameBuf[0] / 255.0f);
+		compo[1] = (CGFloat)(frameBuf[1] / 255.0f);
+		compo[2] = (CGFloat)(frameBuf[2] / 255.0f);
+		compo[3] = (CGFloat)255.0f;
+		
+		CGImageRef tmpCGImg2 = CGImageCreateWithMaskingColors(tmpCGImg, compo);
+		[buf release];
+		buf = [UIImage imageWithCGImage:tmpCGImg2];
+
+		break;
+	} while( 0 );
+
+	pImage = new WSDimage( buf );
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	pImage = NULL;
 
@@ -201,6 +245,11 @@ void Pcg::load( WSCstring path )
 	nHeight = pImage->getImageHeight();
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	nWidth = pImage->getImageWidth();
+	nHeight = pImage->getImageHeight();
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	nWidth = pImage->getImageWidth();
 	nHeight = pImage->getImageHeight();
@@ -373,6 +422,29 @@ bool Pcg::draw( WSDmwindowDev *mDev,
 			0, 0 );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	UIImage *pcgUIImage = pImage->getPixbuf();
+	CGImageRef pcgCGImage = pcgUIImage.CGImage;
+	CGContextRef context = mDev->getPixMap();
+	
+	CGRect pcgRect;
+	pcgRect.size = pcgUIImage.size;
+
+	CGRect clipRect;
+	clipRect.origin.x = x;
+	clipRect.origin.y = -y - h;
+	clipRect.size.width = w;
+	clipRect.size.height = h;
+
+	pcgRect.origin.x = x;
+	pcgRect.origin.y = -y - h;
+
+	CGContextSaveGState(context);
+	CGContextClipToRect(context, clipRect);
+	CGContextDrawImage(context, pcgRect, pcgCGImage);
+	CGContextRestoreGState(context);
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	g_Dir3d.Draw(
 			pImage,
@@ -461,6 +533,29 @@ bool Pcg::drawFix( WSDmwindowDev *mDev,
 					0, 0 );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+			UIImage *pcgUIImage = pImage->getPixbuf();
+			CGImageRef pcgCGImage = pcgUIImage.CGImage;
+			CGContextRef context = mDev->getPixMap();
+			
+			CGRect pcgRect;
+			pcgRect.size = pcgUIImage.size;
+			
+			CGRect clipRect;
+			clipRect.origin.x = xx;
+			clipRect.origin.y = -yy - ih;
+			clipRect.size.width = drawW;
+			clipRect.size.height = drawH;
+			
+			pcgRect.origin.x = xx;
+			pcgRect.origin.y = -yy - ih;
+			
+			CGContextSaveGState(context);
+			CGContextClipToRect(context, clipRect);
+			CGContextDrawImage(context, pcgRect, pcgCGImage);
+			CGContextRestoreGState(context);
+#endif // D_IPHONE
+
 #ifdef D_MFC
 			g_Dir3d.Draw(
 					pImage,
@@ -545,6 +640,29 @@ bool Pcg::drawIdx( WSDmwindowDev *mDev,
 			0, 0 );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	UIImage *pcgUIImage = pImage->getPixbuf();
+	CGImageRef pcgCGImage = pcgUIImage.CGImage;
+	CGContextRef context = mDev->getPixMap();
+	
+	CGRect pcgRect;
+	pcgRect.size = pcgUIImage.size;
+	
+	CGRect clipRect;
+	clipRect.origin.x = x;
+	clipRect.origin.y = -y - sizeY;
+	clipRect.size.width = sizeX;
+	clipRect.size.height = sizeY;
+	
+	pcgRect.origin.x = x - (idxX * sizeX);
+	pcgRect.origin.y = -y - pcgRect.size.height + (idxY * sizeY);
+	
+	CGContextSaveGState(context);
+	CGContextClipToRect(context, clipRect);
+	CGContextDrawImage(context, pcgRect, pcgCGImage);
+	CGContextRestoreGState(context);
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	g_Dir3d.Draw(
 			pImage,
@@ -612,7 +730,6 @@ bool Pcg::drawOffset( WSDmwindowDev *mDev,
 		w = pImage->getImageWidth();
 	if( h > pImage->getImageHeight() )
 		h = pImage->getImageHeight();
-
 	GdkGC	*gc = gMapDrawingArea->style->fg_gc[GTK_STATE_NORMAL];
 
 	gdk_pixbuf_render_to_drawable(
@@ -626,6 +743,38 @@ bool Pcg::drawOffset( WSDmwindowDev *mDev,
 			0, 0 );
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	if( x < 0 )
+		x = 0;
+	if( y < 0 )
+		y = 0;
+	if( w > pImage->getImageWidth() )
+		w = pImage->getImageWidth();
+	if( h > pImage->getImageHeight() )
+		h = pImage->getImageHeight();
+
+	UIImage *pcgUIImage = pImage->getPixbuf();
+	CGImageRef pcgCGImage = pcgUIImage.CGImage;
+	CGContextRef context = mDev->getPixMap();
+	
+	CGRect pcgRect;
+	pcgRect.size = pcgUIImage.size;
+	
+	CGRect clipRect;
+	clipRect.origin.x = x;
+	clipRect.origin.y = -y - h;
+	clipRect.size.width = w;
+	clipRect.size.height = h;
+	
+	pcgRect.origin.x = x - offsetX;
+	pcgRect.origin.y = -y - pcgRect.size.height + offsetY;
+	
+	CGContextSaveGState(context);
+	CGContextClipToRect(context, clipRect);
+	CGContextDrawImage(context, pcgRect, pcgCGImage);
+	CGContextRestoreGState(context);
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	if( w > pImage->getImageWidth() )
 		w = pImage->getImageWidth();
