@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.h,v 1.20 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: Pcg.h,v 1.21 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_H
@@ -47,6 +47,12 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_IPHONE
+# include "IPhoneWSDimage.h"
+# include "IPhoneWSDmwindowDev.h"
+# include "IPhoneWSCstring.h"
+#endif // D_IPHONE
+
 #ifdef D_MFC
 # include "MfcWSDimage.h"
 # include "MfcWSDmwindowDev.h"
