@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.73 2010/05/10 15:31:55 bowkenken Exp $
+* $Id: PcgDun.h,v 1.84 2010/09/01 19:12:02 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -58,6 +58,10 @@
 # include "GtkWSCstring.h"
 #endif //D_GTK
 
+#ifdef D_IPHONE
+# include "IPhoneWSCstring.h"
+#endif //D_IPHONE
+
 #ifdef D_MFC
 # include "MfcWSCstring.h"
 # include "xlnl-dows/Dir3d.h"
@@ -74,19 +78,28 @@
 #if	defined( D_WS )
 # define	STR_GRAPH_FILE_EXT	\
 		"png jpg jpeg bmp " \
-		"PNG JPG JPEG BMP"
+		"PNG JPG JPEG BMP " \
+		"Bmp"
 #elif	defined( D_GTK )
 # define	STR_GRAPH_FILE_EXT	\
 		"png xpm jpg jpeg tif pnm bmp gif " \
-		"PNG XPM JPG JPEG TIF PNM BMP GIF"
+		"PNG XPM JPG JPEG TIF PNM BMP GIF " \
+		"Bmp"
+#elif	defined( D_IPHONE )
+# define	STR_GRAPH_FILE_EXT	\
+		"png jpg jpeg bmp " \
+		"PNG JPG JPEG BMP " \
+		"Bmp"
 #elif	defined( D_MFC )
 # define	STR_GRAPH_FILE_EXT	\
 		"png jpg jpeg bmp " \
-		"PNG JPG JPEG BMP"
+		"PNG JPG JPEG BMP " \
+		"Bmp"
 #else
 # define	STR_GRAPH_FILE_EXT	\
 		"png jpg jpeg bmp " \
-		"PNG JPG JPEG BMP"
+		"PNG JPG JPEG BMP " \
+		"Bmp"
 #endif
 
 // ѥΥơ֥
@@ -113,6 +126,9 @@ typedef enum {
 	N_PTN_DIR_CHR_4 = 4,
 } NPtnDirChr;
 
+const long CUI_TILE_SIZE_X = 32;
+const long CUI_TILE_SIZE_Y = 32;
+
 ////////////////////////////////////////////////////////////////
 
 class PcgDun {
@@ -191,6 +207,19 @@ private:
 	// 󥹥ΥѥΥꥹ
 	Pcg *aPcgMnstr[MNSTR_KIND_MAX_N];
 
+	//  VFX ΥѥΥꥹ
+	Pcg pcgGuiVfxBash;
+	// ƥ빶 VFX ΥѥΥꥹ
+	Pcg pcgGuiVfxBashCrtcl;
+	//  VFX ΥѥΥꥹ
+	Pcg pcgGuiVfxArw;
+	// ʸ VFX ΥѥΥꥹ
+	Pcg *aPcgGuiVfxSpell[RESI_KIND_MAX_N];
+	//  VFX ΥѥΥꥹ
+	Pcg *aPcgGuiVfxBlast[BLAST_KIND_MAX_N];
+	// ǦѤ VFX ΥѥΥꥹ
+	Pcg pcgGuiVfxNinja;
+
 	// 饹ܥ
 	GuiLastBoss lastBossXX;
 
@@ -231,6 +260,11 @@ private:
 	gint nSignboardWidth, nSignboardAscent, nSignboardDescent;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	// եȤΥ
+	void *pSignboardStyle;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	// եȤΥ
 	void *pSignboardStyle;
@@ -263,6 +297,12 @@ private:
 	gint nWidthVfx, nAscentVfx, nDescentVfx;
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	// եȤΥ
+	void *pStyle;
+	void *pStyleVfx;
+#endif // D_IPHONE
+
 #ifdef D_MFC
 	// եȤΥ
 	void *pStyle;
@@ -283,6 +323,7 @@ private:
 	bool bFlgEnaDrawTurn;
 	// ̹׵ե饰
 	bool bFlgUpdateRequest;
+	bool bFlgUpdateRequestIPhone;
 
 public:
 	PcgDun();
@@ -328,6 +369,7 @@ public:
 		bool flgForce = false
 	);
 	void drawTurn( bool flgForce = false );
+	bool drawUpdate( long mapX, long mapY, long mapW, long mapH );
 	void flush( long mapX, long mapY, long mapW, long mapH );
 	bool drawString( long scrn_x, long scrn_y, const char *s, ... );
 	bool drawVfx(
@@ -337,6 +379,8 @@ public:
 	void setXxAttack( xx_act_kind_t kind, void *p );
 
 	void setFlgUpdateRequest( bool flg );
+	void setFlgUpdateRequestIPhone( bool flg );
+	bool getFlgUpdateRequestIPhone();
 
 	bool drawTitle();
 	bool drawLastBoss();
@@ -431,8 +475,14 @@ private:
 */
 	void drawTurnSub();
 	void drawTurnFlush();
-	bool drawSub( long mapX, long mapY, long mapW, long mapH );
 /*
+	bool drawUpdate( long mapX, long mapY, long mapW, long mapH );
+*/
+	bool drawSub(
+		long mapX, long mapY, long mapW, long mapH,
+		bool flgUpdateAll = false
+	);
+	/*
 	void flush( long mapX, long mapY, long mapW, long mapH );
 */
 	void initText();
@@ -455,6 +505,10 @@ private:
 	void setFlgUpdateRequest( bool flg );
 */
 	bool getFlgUpdateRequest();
+/*
+	void setFlgUpdateRequestIPhone( bool flg );
+	bool getFlgUpdateRequestIPhone();
+*/
 	void resetUpdateFlg();
 	void setUpdateFlgRange(
 		long mapX, long mapY,
@@ -525,6 +579,16 @@ private:
 		chr_t *chr, Pcg *pPcg,
 		bool flagOneTile
 	);
+	bool drawGuiVfx( long mapX, long mapY );
+	bool drawGuiVfxBash( long mapX, long mapY, gui_vfx_t *vfx, Pcg *p );
+	bool drawGuiVfxArw( long mapX, long mapY, gui_vfx_t *vfx, Pcg *p );
+	bool drawGuiVfxCommon(
+		long mapX, long mapY, gui_vfx_t *vfx, Pcg *p
+	);
+	Pcg *srchPcgLsNinja( spell_kind_t kind, Pcg *ls );
+	bool drawGuiVfxNinja(
+		long mapX, long mapY, gui_vfx_t *vfx, Pcg *p
+	);
 	void drawNight( long mapX, long mapY, long mapW, long mapH );
 	void drawGameOverFade( long mapX, long mapY, long mapW, long mapH );
 /*
