@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.32 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.38 2010/09/02 17:38:17 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -1923,4 +1923,194 @@ PcgTab gPcgTabMnstrHyper[] = {
 	},
 };
 
+const long nGuiVfxBashAnimMax = 8;
+PcgTab gPcgTabGuiVfxBash[] = {
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/bash/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+const long nGuiVfxBashCrtclAnimMax = 12;
+PcgTab gPcgTabGuiVfxBashCrtcl[] = {
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/bash/critical/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabGuiVfxArw[] = {
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/arrow/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabGuiVfxSpell[] = {
+	{
+		// 
+		RESI_KIND_KNOC,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/knock/",
+	},
+	{
+		// ·
+		RESI_KIND_SLAS,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/slash/",
+	},
+	{
+		// 
+		RESI_KIND_STIN,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/sting/",
+	},
+	{
+		// Ǯ
+		RESI_KIND_HEAT,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/fire/",
+	},
+	{
+		// 
+		RESI_KIND_COLD,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/water/",
+	},
+	{
+		// 
+		RESI_KIND_MIND,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/air/",
+	},
+	{
+		// ڻ
+		RESI_KIND_ACID,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/earth/",
+	},
+	{
+		// 
+		RESI_KIND_ELEC,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/light/",
+	},
+	{
+		// 
+		RESI_KIND_POIS,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/spell/dark/",
+	},
+	{
+		RESI_KIND_SLAS,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabGuiVfxBlast[] = {
+	{
+		// 
+		BLAST_KIND_STD,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/blast/std/",
+	},
+	{
+		// ڤ
+		BLAST_KIND_NINJA_CRTCL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/blast/ninja_crtcl/",
+	},
+	{
+		// ˲μʸ
+		BLAST_KIND_WORD_OF_DESTRUCTION,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/blast/word_of_destruction/",
+	},
+	{
+		BLAST_KIND_STD,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+const long nGuiVfxNinjaTyphoonAnimMax = 8;
+const long nGuiVfxNinjaConflagrationAnimMax = 10;
+const long nGuiVfxNinjaThundercloudAnimMax = 8;
+const long nGuiVfxNinjaInundationAnimMax = 8;
+PcgTab gPcgTabGuiVfxNinja[] = {
+	{
+		// -
+		SPELL_KIND_TYPHOON,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/ninja/typhoon/",
+	},
+	{
+		// -к
+		SPELL_KIND_CONFLAGRATION,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/ninja/conflagration/",
+	},
+	{
+		// -
+		SPELL_KIND_THUNDERCLOUD,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/ninja/thundercloud/",
+	},
+	{
+		// -
+		SPELL_KIND_INUNDATION,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"vfx/ninja/inundation/",
+	},
+	{
+		SPELL_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 #endif /* PCG_DUN_TAB_H */
