@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: SelConf.h,v 1.13 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: SelConf.h,v 1.14 2010/07/08 18:16:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef SEL_CONF_H
@@ -42,7 +42,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#if defined( D_WS ) || defined( D_GTK )
+#if defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
 # include <dirent.h>
 # include <sys/stat.h>
 #endif
