@@ -13,12 +13,13 @@ void	init_auto_mark_all_mbr( void );
 void	init_auto_mark_mbr( long ls_mbr_n );
 void	init_auto_mark_new_mbr( long ls_mbr_n );
 void	set_dflt_auto_mark_mbr( long ls_mbr_n );
-void	set_dflt_auto_mark( long ls_mbr_n, auto_mark_t *p );
+void	set_dflt_auto_mark( long ls_mbr_n, auto_mark_t ls[] );
 auto_mark_t	*srch_dflt_auto_mark( long ls_mbr_n, dflt_auto_mark_t n );
 void	ver_up_auto_mark_1_0_4( long ls_mbr_n );
 void	ver_up_auto_mark_1_1_1( long ls_mbr_n );
 void	ver_up_auto_mark_1_1_3( void );
 void	ver_up_auto_mark_1_2_35( void );
+void	ver_up_auto_mark_1_2_36( void );
 void	cv_msg_ttl_auto_mark( char *ttl );
 char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
 void	set_menu_auto_mark( menu_t **dflt );
@@ -34,6 +35,7 @@ char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_edit_init(
 	menu_t **pp, menu_t **dflt
 );
+char	*cb_menu_auto_mark_position( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_trgt_init(
 	menu_t **pp, menu_t **dflt
 );
@@ -84,6 +86,7 @@ bool_t	arrange_auto_mark( long n, long d );
 bool_t	arrange_auto_mark_mbr_1( long n, long d );
 bool_t	arrange_auto_mark_mbr( long ls_mbr_n, long d );
 bool_t	remove_auto_mark_mbr( long ls_mbr_n );
+char	*get_msg_menu_auto_mark_edit_position( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
@@ -94,7 +97,9 @@ char	*get_msg_ttl_auto_mark_code( long n );
 char	*get_msg_ttl_auto_mark_name( long n );
 char	*get_msg_ttl_auto_mark_info( long n );
 char	*get_msg_ttl_auto_mark_hint( long n );
-auto_mark_t	*get_ls_auto_mark( long ls_mbr_n );
+auto_mark_t	*get_auto_mark(
+	long ls_mbr_n, long auto_mark_n, position_kind_t position_kind
+);
 bool_t	chk_flg_ena_auto_mark( long n );
 void	set_flg_ena_auto_mark( long n, bool_t flg );
 auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
