@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.22 2010/06/04 11:57:29 bowkenken Exp $
+* $Id: amenu.h,v 1.23 2010/06/24 02:14:33 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -54,6 +54,9 @@
 /* ƥμκ */
 #define	AUTO_MARK_APPOINT_ITEM_MAX_N	64
 
+/* С֤饻ѤμưޡåֹѴβ */
+#define	AUTO_MARK_POSITION_MUL	1000
+
 /***************************************************************
 * ե饰
 * ֤Ѥϥ֡ǡ⽤
