@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.h,v 1.53 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: dun.h,v 1.54 2010/08/17 13:57:05 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DUN_H
@@ -249,6 +249,7 @@ typedef struct {
 ***************************************************************/
 
 struct chr_t;
+struct gui_vfx_t;
 
 typedef struct {
 	/* ֥ȤΥ쥤䡼 */
@@ -259,6 +260,8 @@ typedef struct {
 	map_t	total;
 	/* VFX Υ쥤䡼 */
 	char	vfx[MAP_MAX_Y][MAP_MAX_X * 2];
+	/* GUI VFX Υ쥤䡼 */
+	struct gui_vfx_t	*gui_vfx[MAP_MAX_Y][MAP_MAX_X];
 
 	/*  */
 	sect_t	sect[MAP_MAX_Y][MAP_MAX_X];
