@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-replay.c,v 1.4 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: gf-replay.c,v 1.5 2010/05/16 19:34:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -70,7 +70,7 @@ bool_t	load_game_replay( bool_t flg_txt_data, long n )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GAME_DATA_VER_MJR,
 			GAME_DATA_VER_MNR,
 			GAME_DATA_VER_PAT ) ){
