@@ -6,8 +6,8 @@ extern "C" {
 
 void	init_game_file( void );
 void	reset_static_game_file( void );
-char	*init_dir_game( char *home, char *dir, bool_t flg_GPL );
-char	*get_home_dir( void );
+char	*init_dir_game( const char *home, const char *dir, bool_t flg_GPL );
+const char	*get_home_dir( void );
 void	get_path_game_data_txt( char *path, long n );
 void	get_path_game_data_bin( char *path, long n );
 void	get_path_game_data_cnf( char *path, long n );
@@ -47,6 +47,8 @@ square_dir_t	trans_idx_to_square_dir( long idx );
 long	trans_square_dir_to_idx( square_dir_t dir );
 chr_kind_t	trans_idx_to_chr_kind( long idx );
 long	trans_chr_kind_to_idx( chr_kind_t k );
+position_kind_t	trans_idx_to_position_kind( long idx );
+long	trans_position_kind_to_idx( position_kind_t k );
 main_race_t	trans_idx_to_main_race_kind( long idx );
 long	trans_main_race_kind_to_idx( main_race_t k );
 sub_race_t	trans_idx_to_sub_race_kind( long idx );
@@ -75,6 +77,8 @@ auto_mark_act_t	trans_idx_to_am_act( long idx );
 long	trans_am_act_to_idx( auto_mark_act_t k );
 auto_mark_cond_t	trans_idx_to_am_cond( long idx );
 long	trans_am_cond_to_idx( auto_mark_cond_t k );
+dflt_auto_mark_t	trans_idx_to_am_dflt( long idx );
+long	trans_am_dflt_to_idx( dflt_auto_mark_t k );
 attitude_t	trans_idx_to_attitude_kind( long idx );
 long	trans_attitude_kind_to_idx( attitude_t k );
 item_kind_t	trans_idx_to_item_kind( long idx );
@@ -127,6 +131,7 @@ rare_goods_kind_t	trans_idx_to_rare_goods_kind( long idx );
 long	trans_rare_goods_kind_to_idx( rare_goods_kind_t k );
 coin_kind_t	trans_idx_to_coin_kind( long idx );
 long	trans_coin_kind_to_idx( coin_kind_t k );
+long	get_spell_kind_trans_tab_max_n( void );
 spell_kind_t	trans_idx_to_spell_kind( long idx );
 long	trans_spell_kind_to_idx( spell_kind_t k );
 mnstr_kind_t	trans_idx_to_mnstr_kind( long idx );
@@ -137,12 +142,15 @@ fx_kind_t	trans_idx_to_fx_kind( long idx );
 long	trans_fx_kind_to_idx( fx_kind_t k );
 request_kind_t	trans_idx_to_request_kind( long idx );
 long	trans_request_kind_to_idx( request_kind_t k );
+long	get_stay_inn_kind_trans_tab_max_n( void );
+stay_inn_kind_t	trans_idx_to_stay_inn_kind( long idx );
+long	trans_stay_inn_kind_to_idx( request_kind_t k );
 bool_t	copy_file( const char *src, const char *dst );
-char	*cat_path( char *path, char *file );
-bool_t	chk_exist_file( char *s );
-bool_t	chk_exist_dir( char *s );
-bool_t	make_dir( char *path );
-bool_t	make_dir_node( char *path );
+char	*cat_path( const char *path, const char *file );
+bool_t	chk_exist_file( const char *s );
+bool_t	chk_exist_dir( const char *s );
+bool_t	make_dir( const char *path );
+bool_t	make_dir_node( const char *path );
 char	*cv_esc_quote_c( const long c );
 char	*cv_esc_quote_str( const char *str );
 char	*cv_esc_ctrl_str( const char *str );
@@ -189,6 +197,14 @@ bool_t	load_game_conf_id_char_str(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id, long c, char *str
 );
+bool_t	load_game_conf_id_num_str(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, long n, char *str
+);
+bool_t	load_game_conf_id_str_num_str(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, char *str1, long n, char *str2
+);
 bool_t	load_game_conf_id_char(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id, long c
@@ -200,16 +216,27 @@ bool_t	load_game_conf_id_brace(
 bool_t	load_game_conf_lang( char *id, char *str );
 bool_t	load_game_conf_clk_tck( char *id, long val );
 bool_t	load_game_conf_screen_size_auto( char *id, long val );
-bool_t	load_game_conf_screen_size_lines( char *id, long val );
+bool_t	load_game_conf_screen_size_col( char *id, long val );
+bool_t	load_game_conf_screen_size_row( char *id, long val );
+bool_t	load_game_conf_screen_size_message( char *id, long val );
+bool_t	load_game_conf_screen_resize_map( char *id, long val );
 bool_t	load_game_conf_scroll( char *id, char *str );
+bool_t	load_game_conf_cursor_number_main( char *id, long val );
+bool_t	load_game_conf_cursor_number_sub( char *id, long val );
 bool_t	load_game_conf_joystick_kind( char *id, char *str );
 bool_t	load_game_conf_clr_key_buf_every( char *id, long val );
 bool_t	load_game_conf_clr_key_buf_menu( char *id, long val );
 bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
+bool_t	load_game_conf_stat_bar_hint_chr( char *id, long val );
+bool_t	load_game_conf_stat_bar_hint_obj( char *id, long val );
 bool_t	load_game_conf_move_crsr_dflt( char *id, long val );
+bool_t	load_game_conf_double_click_wait( char *id, long val );
+bool_t	load_game_conf_music_volume( char *id, long val );
+bool_t	load_game_conf_sound_volume( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
+bool_t	load_game_conf_audio_buf_siz( char *id, long val );
 bool_t	load_game_conf_gnome( char *id, long val );
 bool_t	load_game_conf_set_window_position( char *id, long val );
 bool_t	load_game_conf_win_pos( char *id, long val, win_kind_t kind );
@@ -225,6 +252,9 @@ bool_t	load_game_conf_attribute_blink( char *id, long val );
 bool_t	load_game_conf_attribute_bold( char *id, long val );
 bool_t	load_game_conf_set_key( char *id, long c, char *str );
 bool_t	load_game_conf_unset_key( char *id, long c );
+bool_t	load_game_conf_set_macro_func(
+	char *id, char *joy, long n, char *macro
+);
 bool_t	load_game_conf_menu(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id
@@ -255,10 +285,14 @@ bool_t	save_game_conf_language( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_frame_rate( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_screen_size( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_crsr_ptn_n( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_audio_buf_siz( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_mouse( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_sound( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_joystick( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_vfx( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_color( FILE *fp, const ver_t *ver );
@@ -267,6 +301,15 @@ bool_t	save_game_conf_color_sub(
 );
 bool_t	save_game_conf_user_menu( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_key_tab( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_func( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_func_sub(
+	FILE *fp,
+	const ver_t *ver,
+	const char *tag,
+	const char *joy,
+	long n,
+	const char *macro
+);
 bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
 bool_t	save_game_data_cnf_contents(
 	FILE *fp, const ver_t *ver
@@ -293,6 +336,7 @@ bool_t	load_crsr_ptn_head( FILE *fp, crsr_ptn_t *ptn );
 bool_t	load_crsr_ptn_misc( FILE *fp, crsr_ptn_t *ptn );
 bool_t	load_crsr_ptn_data( FILE *fp, crsr_ptn_t *ptn );
 bool_t	save_crsr_ptn( crsr_ptn_t *ptn, long max_n );
+void	back_up_crsr_ptn( void );
 void	check_memory_gf_crsr_c( void );
 
 #ifdef __cplusplus
@@ -391,6 +435,9 @@ void	ver_up_game_data_1_1_1( void );
 void	ver_up_game_data_1_1_3( void );
 void	ver_up_game_data_1_2_6( void );
 void	ver_up_game_data_1_2_12( void );
+void	ver_up_game_data_1_2_27( void );
+void	ver_up_game_data_1_2_35( void );
+void	ver_up_game_data_1_2_36( void );
 void	reset_load_game_data( void );
 bool_t	chk_load_game_data( void );
 bool_t	load_game_data_head_ver_1( FILE *fp, ver_t *ver, bool_t flg_txt );
@@ -588,6 +635,18 @@ bool_t	load_game_data_pet_formation_ver_1(
 bool_t	load_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	load_game_data_playing_report_mbr_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	long ls_mbr_n
+);
+bool_t	load_game_data_playing_report_party_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	long ls_mbr_n
+);
+bool_t	load_game_data_playing_report_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	playing_report_t *p
+);
 bool_t	load_game_data_n( FILE *fp, long *n );
 bool_t	load_game_data_s( FILE *fp, char *s, long len );
 bool_t	load_game_data_c( FILE *fp, char *c );
@@ -777,6 +836,16 @@ bool_t	save_game_data_pet_formation_ver_1(
 bool_t	save_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	save_game_data_playing_report_mbr_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_playing_report_party_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_playing_report_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	playing_report_t *p
+);
 bool_t	get_save_load_ttl(
 	char *msg, long n,
 	bool_t flg_txt, bool_t flg_replay
