@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu-tab.h,v 1.14 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: imenu-tab.h,v 1.16 2010/07/21 20:59:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	IMENU_TAB_H
@@ -36,6 +36,63 @@
 menu_t	ls_menu_srch[1 + 4 + MBR_MAX_N + 1];
 menu_t	ls_menu_formation[1 + 1 + MBR_MAX_N + 1];
 
+menu_t	ls_menu_position[] = {
+	{
+		"/position",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_NULL, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/position/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_POSITION, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/position/forward",
+		"<RadioItem>",
+		'F',
+		"",
+		N_MSG_MENU_POSITION_FORWARD, "",
+		cb_menu_position_sel, (void *)POSITION_KIND_FORWARD,
+		FLG_NULL,
+	},
+	{
+		"/position/halfback",
+		"<RadioItem>",
+		'H',
+		"",
+		N_MSG_MENU_POSITION_HALFBACK, "",
+		cb_menu_position_sel, (void *)POSITION_KIND_HALFBACK,
+		FLG_NULL,
+	},
+	{
+		"/position/back",
+		"<RadioItem>",
+		'B',
+		"",
+		N_MSG_MENU_POSITION_BACK, "",
+		cb_menu_position_sel, (void *)POSITION_KIND_BACK,
+		FLG_NULL,
+	},
+	{
+		"",
+		"",
+		'\0',
+		"",
+		N_MSG_NULL, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+};
+
 menu_t	ls_menu_move_crsr[] = {
 	{
 		"/cursor",
@@ -438,7 +495,7 @@ menu_t	ls_menu_mbr_flg[MBR_ITEM_MAX_N + 4];
 
 menu_t	ls_menu_lang_ls[LANG_KIND_MAX_N * 2];
 
-menu_t	ls_menu_color[2 + 1 + CURS_ATTR_MAX_N + 10 + 1];
+menu_t	ls_menu_color[2 + 1 + CURS_ATTR_N_MAX_N + 10 + 1];
 menu_t	ls_menu_color_sel[] = {
 	{
 		"/color",
