@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.103 2009/09/17 22:29:53 bowkenken Exp $
+* $Id: item.h,v 1.105 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -81,6 +81,13 @@
 /* ƥबƤΨ */
 #define	CURSE_ITEM_RATE	((rate_t)30)
 
+/* ȢäƤ륢ƥκǾ */
+#define	CHEST_HOLD_MIN_N	4
+/* ȢäƤ륢ƥκ */
+#define	CHEST_HOLD_MAX_N	8
+/* ٤Ȣκ */
+#define	CAN_CARRY_CHEST_MAX_N	1
+
 /* ƥδ */
 
 #define	FACE_MJR_WEAPON	')'
