@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.85 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: last-boss.c,v 1.90 2010/09/01 09:32:14 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -307,21 +307,21 @@ static void xx_mind_draw( xx_mind_t *xx_mind );
 * XX ڻ
 ***************************************************************/
 
-#define	XX_ACID_HOMING_V	(1.0 * XX_ACID_HOMING_FIX_POINT)
+#define	XX_ACID_HOMING_V	(1 * XX_ACID_HOMING_FIX_POINT)
 
-static const double	XX_ACID_MAX_Q = 18.0;
+static const long	XX_ACID_MAX_Q = 18;
 check_memory_def( check_memory_last_boss_c_XX_ACID_MAX_Q )
 
 static const long	XX_ACID_WAIT_FRAME_N = 3;
 check_memory_def( check_memory_last_boss_c_XX_ACID_WAIT_FRAME_N )
 
 static pos_t	xx_homing_bgn_v[MBR_MAX_N] = {
-	{ -0.1, -XX_ACID_HOMING_V },
-	{ +0.1, -XX_ACID_HOMING_V },
+	{ 0, -XX_ACID_HOMING_V },
+	{ 0, -XX_ACID_HOMING_V },
 	{ -XX_ACID_HOMING_V, -XX_ACID_HOMING_V },
 	{ +XX_ACID_HOMING_V, -XX_ACID_HOMING_V },
-	{ -XX_ACID_HOMING_V, +-0.0 },
-	{ +XX_ACID_HOMING_V, +-0.0 },
+	{ -XX_ACID_HOMING_V, 0 },
+	{ +XX_ACID_HOMING_V, 0 },
 };
 check_memory_def( check_memory_last_boss_c_xx_homing_bgn_v )
 
@@ -2568,7 +2568,7 @@ void	act_mnstr_xx( mnstr_t *p )
 
 #if	0
 	if( g_flg_debug )
-		kind = XX_ACT_KIND_SLAP;
+		kind = XX_ACT_KIND_COLD;
 #endif
 
 	switch( kind ){
@@ -2775,6 +2775,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 						xx_heat.blast_x[n],
 						xx_heat.blast_y[n],
 						&(xx_blast_heat[m]),
+						NULL,
 						"XX" );
 			}
 
@@ -2894,6 +2895,7 @@ void	xx_act_cold_draw( mnstr_t *p )
 					xx_cold.bit_x[n],
 					xx_cold.bit_y[n],
 					&(xx_bit[n]),
+					NULL,
 					NULL );
 		}
 
@@ -2938,10 +2940,10 @@ void	xx_act_cold_draw( mnstr_t *p )
 					curs_attrset_n( CURS_ATTR_N_COLD );
 
 				if( g_flg_gui && g_flg_text_mode ){
-					print_vfx( x, y, MSG_S,
+					print_vfx( FALSE, x, y, MSG_S,
 							xx_laser[n] );
 				} else {
-					print_vfx_cui( x, y, MSG_S,
+					print_vfx_cui( FALSE, x, y, MSG_S,
 							xx_laser[n] );
 				}
 			}
@@ -2952,6 +2954,7 @@ void	xx_act_cold_draw( mnstr_t *p )
 						xx_cold.bit_x[n],
 						xx_cold.bit_y[n],
 						&(xx_bit[n]),
+						NULL,
 						NULL );
 			}
 		}
@@ -3161,9 +3164,9 @@ static void xx_mind_draw( xx_mind_t *xx_mind )
 				curs_attrset_n( CURS_ATTR_N_MIND );
 
 			if( g_flg_gui && g_flg_text_mode )
-				print_vfx( x, y, MSG_S, str );
+				print_vfx( FALSE, x, y, MSG_S, str );
 			else
-				print_vfx_cui( x, y, MSG_S, str );
+				print_vfx_cui( FALSE, x, y, MSG_S, str );
 		}
 	}
 	curs_attrset_dflt();
@@ -3198,8 +3201,8 @@ void	xx_act_acid_draw( mnstr_t *p )
 	xx_acid_t	xx_acid;
 	party_t	*pty;
 	pos_t	bgn;
-	double	mx, my;
-	double	fix;
+	long	mx, my;
+	long	fix;
 	long	m, n, i;
 
 	/*  */
@@ -3281,19 +3284,20 @@ void	xx_act_acid_draw( mnstr_t *p )
 static bool_t xx_acid_chk_end( xx_acid_t *xx_acid )
 {
 	long	head;
-	double	dx, dy;
+	long	dx, dy;
 	long	m;
+	const long adj = XX_ACID_HOMING_FIX_POINT * 110 / _100_PERCENT;
 
 	head = xx_acid->homing_idx;
 
 	for( m = 0; m < MBR_MAX_N; m++ ){
-		dx = fabs( xx_acid->homing_mx[m]
+		dx = labs( xx_acid->homing_mx[m]
 				- xx_acid->homing_x[m][head] );
-		dy = fabs( xx_acid->homing_my[m]
+		dy = labs( xx_acid->homing_my[m]
 				- xx_acid->homing_y[m][head] );
-		if( dx > 1.0 )
+		if( dx > adj )
 			return FALSE;
-		if( dy > 1.0 )
+		if( dy > adj )
 			return FALSE;
 	}
 
@@ -3308,17 +3312,18 @@ static bool_t xx_acid_chk_end( xx_acid_t *xx_acid )
 static void xx_acid_move( xx_acid_t *xx_acid )
 {
 	long	head, prev;
-	double	x, y;
-	double	mx, my;
-	double	vx, vy;
-	double	m_vx, m_vy;
-	double	r_vx, r_vy;
-	double	l_vx, l_vy;
-	double	xx, yy;
-	double	dx, dy;
-	double	d_vec;
+	long	x, y;
+	long	mx, my;
+	long	vx, vy;
+	long	m_vx, m_vy;
+	long	r_vx, r_vy;
+	long	l_vx, l_vy;
+	long	xx, yy;
+	long	dx, dy;
+	long	d_vec;
 	double	q;
-	double	fix;
+	long	fix;
+	long	adj;
 	long	m;
 
 	fix = XX_ACID_HOMING_FIX_POINT;
@@ -3341,7 +3346,7 @@ static void xx_acid_move( xx_acid_t *xx_acid )
 		yy = my - y;
 		xx = xx * xx / fix;
 		yy = yy * yy / fix;
-		d_vec = sqrt( xx + yy );
+		d_vec = (long)sqrt( (double)(xx + yy) );
 		if( d_vec == 0 ){
 			m_vx = 0;
 			m_vy = 0;
@@ -3386,11 +3391,12 @@ static void xx_acid_move( xx_acid_t *xx_acid )
 
 		/* ɸ˶դۤĤ */
 
-		dx = fabs( xx_acid->homing_mx[m]
+		adj = fix * 150 / _100_PERCENT;
+		dx = labs( xx_acid->homing_mx[m]
 				- xx_acid->homing_x[m][head] );
-		dy = fabs( xx_acid->homing_my[m]
+		dy = labs( xx_acid->homing_my[m]
 				- xx_acid->homing_y[m][head] );
-		if( (dx <= 1.5) && (dy <= 1.5) ){
+		if( (dx <= adj) && (dy <= adj) ){
 			xx_acid->homing_x[m][head] = xx_acid->homing_mx[m];
 			xx_acid->homing_y[m][head] = xx_acid->homing_my[m];
 		}
@@ -3407,7 +3413,7 @@ static void xx_acid_draw( xx_acid_t *xx_acid )
 	pos_t	*draw;
 	const char	*str;
 	long	idx;
-	double	fix;
+	long	fix;
 	long	x, y;
 	long	m, n;
 
@@ -3437,9 +3443,9 @@ static void xx_acid_draw( xx_acid_t *xx_acid )
 				curs_attrset_n( CURS_ATTR_N_ACID );
 
 			if( g_flg_gui && g_flg_text_mode )
-				print_vfx( x, y, MSG_S, str );
+				print_vfx( FALSE, x, y, MSG_S, str );
 			else
-				print_vfx_cui( x, y, MSG_S, str );
+				print_vfx_cui( FALSE, x, y, MSG_S, str );
 		}
 	}
 	curs_attrset_dflt();
@@ -3543,10 +3549,10 @@ void	xx_act_rotation_draw( mnstr_t *p )
 					curs_attrset_n( CURS_ATTR_N_COLD );
 
 				if( g_flg_gui && g_flg_text_mode ){
-					print_vfx( x, y, MSG_S,
+					print_vfx( FALSE, x, y, MSG_S,
 							xx_rotation_str );
 				} else {
-					print_vfx_cui( x, y, MSG_S,
+					print_vfx_cui( FALSE, x, y, MSG_S,
 							xx_rotation_str );
 				}
 			}
@@ -3711,10 +3717,13 @@ void	xx_act_whirl_draw( mnstr_t *p )
 			if( g_flg_text_mode )
 				curs_attrset_n( CURS_ATTR_N_HEAT );
 
-			if( g_flg_gui && g_flg_text_mode )
-				print_vfx( x, y, MSG_S, xx_whirl_str );
-			else
-				print_vfx_cui( x, y, MSG_S, xx_whirl_str );
+			if( g_flg_gui && g_flg_text_mode ){
+				print_vfx( FALSE, x, y, MSG_S,
+						xx_whirl_str );
+			} else {
+				print_vfx_cui( FALSE, x, y, MSG_S,
+						xx_whirl_str );
+			}
 		}
 		curs_attrset_dflt();
 
@@ -3856,10 +3865,10 @@ void	xx_act_fan_draw( mnstr_t *p )
 					curs_attrset_n( CURS_ATTR_N_MIND );
 
 				if( g_flg_gui && g_flg_text_mode ){
-					print_vfx( x, y, MSG_S,
+					print_vfx( FALSE, x, y, MSG_S,
 							xx_fan_str );
 				} else {
-					print_vfx_cui( x, y, MSG_S,
+					print_vfx_cui( FALSE, x, y, MSG_S,
 							xx_fan_str );
 				}
 			}
