@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.37 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.39 2010/09/01 08:39:29 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -134,6 +134,9 @@ void	init_main_sel_conf( void *cnf )
 
 void	closeGameGui()
 {
+	if( g_flg_cui )
+		gCuiMouse.close();
+
 	gSound.close();
 	gMusic.close();
 }
@@ -144,7 +147,7 @@ void	closeGameGui()
 
 void	guiMapPrintStatBarHint( void )
 {
-	pos_t *crsr = get_crsr();
+	pos_t *crsr = get_main_crsr();
 	if( crsr == NULL )
 		return;
 
