@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.76 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.79 2010/07/20 22:53:24 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -78,6 +78,7 @@ int	main( int argc, char **argv )
 	init_arg();
 
 	g_flg_gui = TRUE;
+	g_flg_cui_mouse = TRUE;
 
 #if	defined( NDEBUG )
 	g_flg_cui = FALSE;
@@ -93,8 +94,11 @@ int	main( int argc, char **argv )
 	init_game();
 	change_scene_gui( SCENE_N_INIT );
 
+	if( g_flg_cui_mouse )
+		gCuiMouse.init();
+
 	if( g_flg_gui ){
-		init_gtk_win( argc, argv );
+		init_gtk_gui( argc, argv );
 
 		// GUI Υᥤ󡦥롼פ򳫻
 
@@ -102,23 +106,28 @@ int	main( int argc, char **argv )
 
 		// λ
 
-		closeGameGui();
 		close_game( EXIT_SUCCESS );
 
 		gtk_exit( EXIT_SUCCESS );
-	} else {
-		// SDL 
-
-		gMusic.init();
-		gSound.init();
-		gJoystick.init();
-
-		change_scene_gui( SCENE_N_TITLE );
+	} else if( g_flg_cui_mouse ){
+		init_gtk_cui_mouse( argc, argv );
 
 		// CUI Υᥤ󡦥롼פ򳫻
 
 		game_main();
 
+		// λ
+
+		close_game( EXIT_SUCCESS );
+	} else if( g_flg_cui ){
+		init_gtk_cui( argc, argv );
+
+		// CUI Υᥤ󡦥롼פ򳫻
+
+		game_main();
+
+		// λ
+
 		close_game( EXIT_SUCCESS );
 	}
 
@@ -127,12 +136,12 @@ int	main( int argc, char **argv )
 }
 
 ////////////////////////////////////////////////////////////////
-// GTK+ ν
+// GTK+ ν (GUI)
 // int argc : ο
 // char **argv : Υꥹ
 ////////////////////////////////////////////////////////////////
 
-void	init_gtk_win( int argc, char **argv )
+void	init_gtk_gui( int argc, char **argv )
 {
 	// GTK+ 
 
@@ -170,6 +179,77 @@ void	init_gtk_win( int argc, char **argv )
 	gSelConf.draw();
 }
 
+////////////////////////////////////////////////////////////////
+// GTK+ ν (CUI)
+// int argc : ο
+// char **argv : Υꥹ
+////////////////////////////////////////////////////////////////
+
+void	init_gtk_cui( int argc, char **argv )
+{
+	// SDL 
+
+	gMusic.init();
+	gSound.init();
+	gJoystick.init();
+
+	change_scene_gui( SCENE_N_TITLE );
+
+	// åɤڤ
+
+	call_game_thread_create( main_thread_cui );
+}
+
+////////////////////////////////////////////////////////////////
+// GTK+ ν (CUI Mouse)
+// int argc : ο
+// char **argv : Υꥹ
+////////////////////////////////////////////////////////////////
+
+void	init_gtk_cui_mouse( int argc, char **argv )
+{
+	// GTK+ 
+
+	gtk_set_locale();
+
+	g_thread_init( NULL );
+	gdk_threads_init();
+
+	gtk_init( &argc, &argv );
+
+	gPcgDun.nTileSizeRate = g_graph_scale_rate;
+
+	// SDL 
+
+	gMusic.init();
+	gSound.init();
+	gJoystick.init();
+
+	// Ϥν
+
+	gKey.init();
+	initMouseMotionFunc();
+
+	change_scene_gui( SCENE_N_TITLE );
+
+	// åɤڤ
+
+	call_game_thread_create( main_thread_cui );
+}
+
+////////////////////////////////////////////////////////////////
+// ޡѤΥߡΥᥤ󡦥å (CUI)
+// void *p : 
+// return : 
+////////////////////////////////////////////////////////////////
+
+void	*main_thread_cui( void *p )
+{
+	gtk_main();
+
+	return NULL;
+}
+
 ////////////////////////////////////////////////////////////////
 // ޡͭˤ
 ////////////////////////////////////////////////////////////////
@@ -544,8 +624,14 @@ void	init_main_win( void )
 
 void	closeGameGui()
 {
-	gtk_timeout_remove( ghTimer );
+	if( g_flg_cui_mouse )
+		gCuiMouse.close();
+
+	if( g_flg_gui )
+		gtk_timeout_remove( ghTimer );
+
 	gMusic.close();
+	gSound.close();
 }
 
 ////////////////////////////////////////////////////////////////
@@ -554,7 +640,7 @@ void	closeGameGui()
 
 void	guiMapPrintStatBarHint( void )
 {
-	pos_t *crsr = get_crsr();
+	pos_t *crsr = get_main_crsr();
 	if( crsr == NULL )
 		return;
 
