@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: map-event.c,v 1.4 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: map-event.c,v 1.6 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,7 +40,9 @@
 #define	MAP_EVENT_MAX_N	(10 + ('z' - 'a' + 1))
 
 static map_event_func_t	map_event_func[MAP_EVENT_MAX_N];
+check_memory_def( check_memory_map_event_c_map_event_func )
 static pos_t	map_event_pos[MAP_EVENT_MAX_N];
+check_memory_def( check_memory_map_event_c_map_event_pos )
 
 /***************************************************************
 * ޥåס٥Ȥꥻå
@@ -238,3 +240,15 @@ long	cv_face_to_map_event_n( char mnr )
 
 	return n;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_map_event_c( void )
+{
+	check_memory( check_memory_map_event_c_map_event_func,
+			"map-event.c: map_event_func" );
+	check_memory( check_memory_map_event_c_map_event_pos,
+			"map-event.c: map_event_pos" );
+}
