@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.231 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: menu.c,v 1.233 2010/05/13 17:31:58 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -552,6 +552,18 @@ void	init_ls_menu_macro_func( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/unset", fn );
+		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = 'U';
+		ls[k].short_key[0] = '\0';
+		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_UNSET,
+				MENU_MSG_MAX_BYTE );
+		ls[k].call_back = cb_menu_func_unset;
+		ls[k].arg = (void *)macro_n;
+		ls[k].flg = FLG_NULL;
+		k++;
+
 		key++;
 	}
 	ls[k].path[0] = '\0';
@@ -816,6 +828,18 @@ void	init_ls_menu_macro_mouse_sub(
 	ls[k].flg = FLG_NULL;
 	k++;
 
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+			"/mouse/%ld/unset", macro_n );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'U';
+	ls[k].short_key[0] = '\0';
+	str_nz_cpy( ls[k].msg, MSG_MENU_MOUSE_UNSET,
+			MENU_MSG_MAX_BYTE );
+	ls[k].call_back = cb_menu_func_unset;
+	ls[k].arg = (void *)macro_n;
+	ls[k].flg = FLG_NULL;
+	k++;
+
 	key++;
 
 	*kp = k;
@@ -1147,6 +1171,18 @@ void	init_ls_menu_macro_joystick( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/joystick/%ld/unset", fn );
+		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = 'U';
+		ls[k].short_key[0] = '\0';
+		str_nz_cpy( ls[k].msg, MSG_MENU_JOYSTICK_UNSET,
+				MENU_MSG_MAX_BYTE );
+		ls[k].call_back = cb_menu_func_unset;
+		ls[k].arg = (void *)macro_n;
+		ls[k].flg = FLG_NULL;
+		k++;
+
 		key++;
 	}
 	ls[k].path[0] = '\0';
@@ -1473,7 +1509,7 @@ bool_t	set_menu_radio_item( menu_t *ls, menu_t *p )
 
 /**/
 
-ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel )
+ask_t	exec_menu_ask( const char *ttl, ask_t dflt, bool_t can_cancel )
 {
 	if( ttl != NULL )
 		print_msg( FLG_NULL, MSG_S, ttl );
@@ -1483,7 +1519,9 @@ ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel )
 
 /**/
 
-ask_t	exec_menu_ask_no_msg( char *ttl, ask_t dflt, bool_t can_cancel )
+ask_t	exec_menu_ask_no_msg(
+	const char *ttl, ask_t dflt, bool_t can_cancel
+)
 {
 	menu_t	*p;
 	char	*str_goto;
@@ -2070,7 +2108,7 @@ long	set_ls_menu(
 
 /**/
 
-menu_t	*srch_menu( menu_t *ls, char *sub_path )
+menu_t	*srch_menu( menu_t *ls, const char *sub_path )
 {
 	long	idx;
 	menu_t *p;
