@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.51 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: menu.h,v 1.54 2010/07/22 00:58:05 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -87,6 +87,10 @@
 /* ܿ */
 #define	MENU_MAX_N	(MENU_MAX_N_PER_PAGE * MENU_MAX_PAGE)
 
+/**** ե饰 ****/
+
+typedef unsigned long	flg_menu_t;
+
 /* ̵ */
 #define	FLG_MENU_DIS	(1 << 0)
 
@@ -103,6 +107,8 @@
 	(FLG_MENU_DIS | FLG_MENU_HIDDEN \
 	| FLG_MENU_CHK_ON | FLG_MENU_CHK_OFF)
 
+/****  ****/
+
 /* ˥塼ѥκʸ */
 #define	MENU_PATH_MAX_LEN	80
 
@@ -152,43 +158,6 @@ typedef unsigned long	flg_scroll_t;
 #define	FLG_SCROLL_SMOOTH	(1 << 0)
 #define	FLG_SCROLL_CENTER	(1 << 1)
 
-/**** ե󥯥󡦥 ****/
-
-/* ե󥯥󡦥κ */
-#define	FUNC_KEY_MAX	80
-
-/**** ޥ⡼бե󥯥󡦥 ****/
-
-typedef enum {
-	FUNC_N_CLICK_L = 21,
-	FUNC_N_CLICK_M,
-	FUNC_N_CLICK_R,
-	FUNC_N_CLICK_0 = FUNC_N_CLICK_L,
-
-	FUNC_N_DBL_CLICK_L = 31,
-	FUNC_N_DBL_CLICK_M,
-	FUNC_N_DBL_CLICK_R,
-	FUNC_N_DBL_CLICK_0 = FUNC_N_DBL_CLICK_L,
-
-	FUNC_N_PRESS_L_CLICK_R = 41,
-	FUNC_N_PRESS_R_CLICK_L,
-
-	FUNC_N_PRESS_L = 51,
-	FUNC_N_PRESS_M,
-	FUNC_N_PRESS_R,
-	FUNC_N_PRESS_0 = FUNC_N_PRESS_L,
-
-	FUNC_N_RELEASE_L = 61,
-	FUNC_N_RELEASE_M,
-	FUNC_N_RELEASE_R,
-	FUNC_N_RELEASE_0 = FUNC_N_RELEASE_L,
-
-	FUNC_N_MOTION_LEFT = 71,
-	FUNC_N_MOTION_RIGHT,
-	FUNC_N_MOTION_UP,
-	FUNC_N_MOTION_DOWN,
-} func_n_t;
-
 /***************************************************************/
 
 /* ˥塼 */
@@ -214,7 +183,7 @@ typedef struct menu_t {
 	void	*arg;
 
 	/* ե饰 */
-	unsigned long	flg;
+	flg_menu_t	flg;
 } menu_t;
 
 typedef struct {
