@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.59 2010/05/13 17:31:58 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.68 2010/08/04 00:40:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -40,6 +40,11 @@
 
 /**/
 
+/* С֥˥塼ͭ/̵ե饰 */
+#define	FLG_ENA_MISC_POSITION	0
+
+/**/
+
 menu_t	ls_menu_main_race[] = {
 	{
 		"/main race",
@@ -402,7 +407,7 @@ menu_t	ls_menu_main[] = {
 		'I',
 		"",
 		N_MSG_MENU_INFO, "",
-		NULL, NULL,
+		cb_menu_info, NULL,
 		FLG_NULL,
 	},
 	{
@@ -424,7 +429,25 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/info/list message",
+		"/misc/info/switch status mode",
+		"<Item>",
+		'Z',
+		"Z",
+		N_MSG_MENU_SWITCH_STAT_MODE, "",
+		cb_menu_switch_stat_mode, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/info/message",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_MSG, "",
+		cb_menu_msg, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/info/message/list",
 		"<OpenWinItem>",
 		'L',
 		"g",
@@ -432,6 +455,24 @@ menu_t	ls_menu_main[] = {
 		cb_menu_ls_msg, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/info/message/prev",
+		"<Item>",
+		'P',
+		"",
+		N_MSG_MENU_SCROLL_MSG_PREV, "",
+		cb_menu_scroll_msg, (void *)-1,
+		FLG_NULL,
+	},
+	{
+		"/misc/info/message/next",
+		"<Item>",
+		'N',
+		"",
+		N_MSG_MENU_SCROLL_MSG_NEXT, "",
+		cb_menu_scroll_msg, (void *)+1,
+		FLG_NULL,
+	},
 	{
 		"/misc/info/list key item",
 		"<Item>",
@@ -558,6 +599,7 @@ menu_t	ls_menu_main[] = {
 		cb_menu_formation, NULL,
 		FLG_NULL,
 	},
+#if	FLG_ENA_MISC_POSITION
 	{
 		"/misc/position",
 		"<Branch>",
@@ -567,6 +609,7 @@ menu_t	ls_menu_main[] = {
 		cb_menu_position, NULL,
 		FLG_NULL,
 	},
+#endif
 	{
 		"/misc/cursor",
 		"<Branch>",
@@ -646,7 +689,7 @@ menu_t	ls_menu_main[] = {
 		'R',
 		"",
 		N_MSG_MENU_RESET_FILE, "",
-		NULL, NULL,
+		cb_menu_set_dflt_cnf, NULL,
 		FLG_NULL,
 	},
 	{
@@ -659,7 +702,16 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/reset file/town ptn",
+		"/misc/config/reset file/cursor pattern",
+		"<Item>",
+		'S',
+		"",
+		N_MSG_MENU_RESET_FILE_CRSR_PTN, "",
+		cb_menu_reset_file_crsr_ptn, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/reset file/town pattern",
 		"<Item>",
 		'T',
 		"",
@@ -710,7 +762,7 @@ menu_t	ls_menu_main[] = {
 		'V',
 		"",
 		N_MSG_MENU_SCREEN, "",
-		NULL, NULL,
+		cb_menu_set_dflt_cnf, NULL,
 		FLG_NULL,
 	},
 	{
@@ -785,6 +837,33 @@ menu_t	ls_menu_main[] = {
 		cb_menu_mul_msg_line, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/screen/window/status bar",
+		"<Branch>",
+		'B',
+		"",
+		N_MSG_MENU_STAT_BAR, "",
+		cb_menu_stat_bar_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/status bar/hint chr",
+		"<CheckItem>",
+		'C',
+		"",
+		N_MSG_MENU_STAT_BAR_HINT_CHR, "",
+		cb_menu_stat_bar_hint_chr, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/status bar/hint obj",
+		"<CheckItem>",
+		'O',
+		"",
+		N_MSG_MENU_STAT_BAR_HINT_OBJ, "",
+		cb_menu_stat_bar_hint_obj, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/screen/window/size",
 		"<Branch>",
@@ -964,7 +1043,25 @@ menu_t	ls_menu_main[] = {
 		'V',
 		"",
 		N_MSG_MENU_CRSR_PTN, "",
-		cb_menu_crsr_ptn, NULL,
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/cursor pattern/main",
+		"<Branch>",
+		'M',
+		"",
+		N_MSG_MENU_CRSR_PTN_MAIN, "",
+		cb_menu_crsr_ptn, (void *)TRUE,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/cursor pattern/sub",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_CRSR_PTN_SUB, "",
+		cb_menu_crsr_ptn, (void *)FALSE,
 		FLG_NULL,
 	},
 	{
@@ -1136,16 +1233,43 @@ menu_t	ls_menu_main[] = {
 		'G',
 		"",
 		N_MSG_MENU_GUI, "",
-		cb_menu_gui, NULL,
+		cb_menu_set_dflt_cnf, NULL,
 		FLG_NULL,
 	},
 	{
-		"/misc/config/gui/move cursor to default",
+		"/misc/config/gui/mouse",
+		"<Branch>",
+		'M',
+		"",
+		N_MSG_MENU_MOUSE, "",
+		cb_menu_mouse_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse/move cursor to default",
 		"<CheckItem>",
 		'C',
 		"",
 		N_MSG_MENU_MOVE_CRSR_DFLT, "",
-		cb_menu_move_crsr_dflt, NULL,
+		cb_menu_mouse_move_crsr_dflt, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse/double click",
+		"<OpenWinItem>",
+		'W',
+		"",
+		N_MSG_MENU_MOUSE_DOUBLE_CLICK, "",
+		cb_menu_mouse_double_click, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse/assign",
+		"<Branch>",
+		'B',
+		"",
+		N_MSG_MENU_MOUSE_ASSIGN, "",
+		cb_menu_mouse, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1202,15 +1326,6 @@ menu_t	ls_menu_main[] = {
 		cb_menu_set_audio_buf_siz, NULL,
 		FLG_NULL,
 	},
-	{
-		"/misc/config/gui/mouse",
-		"<Branch>",
-		'M',
-		"",
-		N_MSG_MENU_MOUSE, "",
-		cb_menu_mouse, NULL,
-		FLG_NULL,
-	},
 	{
 		"/misc/config/gui/joystick",
 		"<Branch>",
@@ -1268,7 +1383,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/config/gui/joystick/macro",
 		"<Branch>",
-		'M',
+		'B',
 		"",
 		N_MSG_MENU_JOYSTICK_MACRO, "",
 		cb_menu_joystick_macro_init, NULL,
@@ -1301,7 +1416,7 @@ menu_t	ls_menu_main[] = {
 		'R',
 		"",
 		N_MSG_MENU_REPLAY, "",
-		NULL, NULL,
+		cb_menu_set_dflt_system, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1411,7 +1526,7 @@ menu_t	ls_menu_main[] = {
 		'T',
 		"",
 		N_MSG_MENU_WIZARD_ADD_TURN, "",
-		NULL, NULL,
+		cb_menu_set_dflt_wizard, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1474,7 +1589,7 @@ menu_t	ls_menu_main[] = {
 		'C',
 		"",
 		N_MSG_MENU_WIZARD_SCENE, "",
-		NULL, NULL,
+		cb_menu_set_dflt_wizard, NULL,
 		FLG_NULL,
 	},
 	{
