@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-tab.h,v 1.15 2009/02/22 10:36:45 bowkenken Exp $
+* $Id: mnstr-tab.h,v 1.18 2010/08/04 19:28:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_TAB_H
@@ -111,7 +111,7 @@ mnstr_lev_tab_t	mnstr_boss_lev_tab[] = {
 		+0, +1, 80, 80, },
 	{ MNSTR_KIND_RELATIVISTIC_DAEMON,	/*  */
 		+0, +1, 90, 90, },
-	{ MNSTR_KIND_ETERNAL_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_ETERNAL_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +1, 100, 100, },
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
@@ -272,11 +272,11 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_4[] = {
 		+0, +0, 34, 36, },
 	{ MNSTR_KIND_ACID_FLY,	/*  */
 		+0, +0, 35, 37, },
-	{ MNSTR_KIND_AIR_ELEMENTAL,	/*  */
+	{ MNSTR_KIND_EARTH_ELEMENTAL,	/*  */
 		+0, +0, 36, 38, },
 	{ MNSTR_KIND_SPORE,	/* ʪ */
 		+0, +0, 37, 39, },
-	{ MNSTR_KIND_EARTH_ELEMENTAL,	/*  */
+	{ MNSTR_KIND_AIR_ELEMENTAL,	/*  */
 		+0, +0, 38, 40, },
 	{ MNSTR_KIND_INCUBUS,	/*  */
 		+0, +0, 39, 41, },
@@ -348,11 +348,11 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_7[] = {
 		+0, +0, 63, 65, },
 	{ MNSTR_KIND_MUMMY,	/* ǥå */
 		+0, +0, 64, 66, },
-	{ MNSTR_KIND_SYLPH,	/*  */
+	{ MNSTR_KIND_GNOME,	/*  */
 		+0, +0, 65, 67, },
 	{ MNSTR_KIND_UNICORN,	/*  */
 		+0, +0, 66, 68, },
-	{ MNSTR_KIND_GNOME,	/*  */
+	{ MNSTR_KIND_SYLPH,	/*  */
 		+0, +0, 67, 69, },
 	{ MNSTR_KIND_GARGOYLE,	/* ˡʪ */
 		+0, +0, 68, 70, },
@@ -370,9 +370,9 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_8[] = {
 		+0, +0, 71, 73, },
 	{ MNSTR_KIND_M_BLUE_DRAGON,	/* --ޥʡɥ饴 */
 		+0, +0, 72, 74, },
-	{ MNSTR_KIND_M_GREEN_DRAGON,	/* --ޥʡɥ饴 */
-		+0, +0, 73, 75, },
 	{ MNSTR_KIND_M_YELLOW_DRAGON,	/* --ޥʡɥ饴 */
+		+0, +0, 73, 75, },
+	{ MNSTR_KIND_M_GREEN_DRAGON,	/* --ޥʡɥ饴 */
 		+0, +0, 74, 76, },
 	{ MNSTR_KIND_M_WHITE_DRAGON,	/* --ޥʡɥ饴 */
 		+0, +0, 75, 77, },
@@ -418,46 +418,46 @@ mnstr_lev_tab_t	mnstr_lev_tab_stage_9[] = {
 /* BOSS MNSTR_KIND_RELATIVISTIC_DAEMON, */	/*  */
 
 mnstr_lev_tab_t	mnstr_lev_tab_stage_10[] = {
-	{ MNSTR_KIND_A_RED_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_RED_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 91, 93, },
 	{ MNSTR_KIND_VAMPIRE,	/* ǥå */
 		+0, +0, 91, 93, },
-	{ MNSTR_KIND_A_BLUE_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_BLUE_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 92, 94, },
 	{ MNSTR_KIND_GORGON,	/*  */
 		+0, +0, 92, 94, },
-	{ MNSTR_KIND_A_YELLOW_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_YELLOW_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 93, 95, },
 	{ MNSTR_KIND_EFREET,	/*  */
 		+0, +0, 93, 95, },
-	{ MNSTR_KIND_A_GREEN_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_GREEN_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 94, 96, },
 	{ MNSTR_KIND_DJINNI,	/*  */
 		+0, +0, 94, 96, },
-	{ MNSTR_KIND_A_WHITE_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_WHITE_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 95, 97, },
 	{ MNSTR_KIND_BASILISK,	/*  */
 		+0, +0, 95, 97, },
-	{ MNSTR_KIND_A_BLACK_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_BLACK_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 96, 98, },
 	{ MNSTR_KIND_HELLHOUND,	/*  */
 		+0, +0, 96, 98, },
-	{ MNSTR_KIND_A_COPPER_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_COPPER_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 97, 99, },
 	{ MNSTR_KIND_SPIRIT,	/* ǥå */
 		+0, +0, 97, 99, },
-	{ MNSTR_KIND_A_SILVER_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_SILVER_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 98, 100, },
 	{ MNSTR_KIND_GREATER_DAEMON,	/*  */
 		+0, +0, 98, 100, },
-	{ MNSTR_KIND_A_GOLD_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_GOLD_DRAGON,	/* 󥷥ȡɥ饴 */
 		+0, +0, 99, 100, },
 	{ MNSTR_KIND_PHOENIX,	/*  */
 		+0, +0, 100, 100, },
 	{ MNSTR_KIND_NULL,
 		+0, +0, 0, 0, },
 };
-/* BOSS MNSTR_KIND_ETERNAL_DRAGON, */	/* --󥷥ȡɥ饴 */
+/* BOSS MNSTR_KIND_ETERNAL_DRAGON, */	/* 󥷥ȡɥ饴 */
 
 mnstr_lev_tab_t	mnstr_lev_tab[MNSTR_KIND_MAX_N + 1];
 
@@ -588,10 +588,10 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_ANDRO_SCORPION,	/* Ⱦ */
 		+1, +5, },
-	{ MNSTR_KIND_AIR_ELEMENTAL,	/*  */
-		+1, +5, },
 	{ MNSTR_KIND_EARTH_ELEMENTAL,	/*  */
 		+1, +5, },
+	{ MNSTR_KIND_AIR_ELEMENTAL,	/*  */
+		+1, +5, },
 	{ MNSTR_KIND_LAMIA,	/* Ⱦ */
 		+1, +5, },
 	{ MNSTR_KIND_CENTAUR,	/* Ⱦ */
@@ -648,21 +648,21 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_BANSHEE,	/* ǥå */
 		+1, +5, },
-	{ MNSTR_KIND_SYLPH,	/*  */
-		+1, +5, },
 	{ MNSTR_KIND_GNOME,	/*  */
 		+1, +5, },
+	{ MNSTR_KIND_SYLPH,	/*  */
+		+1, +5, },
 	{ MNSTR_KIND_WYVERN,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_MEDUSA,	/* Ⱦ */
 		+1, +5, },
-	{ MNSTR_KIND_M_RED_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_RED_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
-	{ MNSTR_KIND_M_BLUE_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_BLUE_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
-	{ MNSTR_KIND_M_YELLOW_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_YELLOW_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
-	{ MNSTR_KIND_M_GREEN_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_GREEN_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
 	{ MNSTR_KIND_WRAITH,	/* ǥå */
 		+1, +5, },
@@ -670,9 +670,9 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_LESSER_DAEMON,	/*  */
 		+1, +5, },
-	{ MNSTR_KIND_M_WHITE_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_WHITE_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
-	{ MNSTR_KIND_M_BLACK_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_BLACK_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
 	{ MNSTR_KIND_COCKATRICE,	/*  */
 		+1, +5, },
@@ -680,11 +680,11 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_VAMPIRE,	/* ǥå */
 		+1, +5, },
-	{ MNSTR_KIND_M_COPPER_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_COPPER_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
-	{ MNSTR_KIND_M_SILVER_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_SILVER_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
-	{ MNSTR_KIND_M_GOLD_DRAGON,	/* --ޥʡɥ饴 */
+	{ MNSTR_KIND_M_GOLD_DRAGON,	/* ޥʡɥ饴 */
 		+1, +2, },
 	{ MNSTR_KIND_GORGON,	/*  */
 		+1, +5, },
@@ -702,23 +702,23 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_GREATER_DAEMON,	/*  */
 		+1, +5, },
-	{ MNSTR_KIND_A_RED_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_RED_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_BLUE_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_BLUE_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_YELLOW_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_YELLOW_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_GREEN_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_GREEN_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_WHITE_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_WHITE_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_BLACK_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_BLACK_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_COPPER_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_COPPER_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_SILVER_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_SILVER_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
-	{ MNSTR_KIND_A_GOLD_DRAGON,	/* --󥷥ȡɥ饴 */
+	{ MNSTR_KIND_A_GOLD_DRAGON,	/* 󥷥ȡɥ饴 */
 		+1, +5, },
 
 	/**/
