@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.244 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: party.c,v 1.254 2010/08/20 15:38:57 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -220,6 +220,8 @@ void	init_party( void )
 	party.flg = FLG_NULL;
 	party.flg |= FLG_PARTY_SRCH_AUTO_OFF;
 
+	/**/
+
 	if( g_flg_debug )
 		init_party_debug();
 	else
@@ -243,69 +245,85 @@ void	init_party_dflt( void )
 	item_kind_dat_t	sub_kind;
 	long	i;
 
+	i = 0;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
-			MALE, CLASS_N_FIGHTER, 0 );
-	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.bmp",
+	new_mbr( ls_mbr[i], "<///BLADE//}===o", 'B', race,
+			MALE, CLASS_N_FIGHTER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-01.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 1;
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
-			MALE, CLASS_N_FIGHTER, 1 );
-	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.bmp",
+	new_mbr( ls_mbr[i], ")(==DRANK======>", 'D', race,
+			MALE, CLASS_N_FIGHTER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-02.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 2;
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
-			MALE, CLASS_N_HUNTER, 2 );
-	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
+	new_mbr( ls_mbr[i], "<---ELSIE----<<<", 'E', race,
+			MALE, CLASS_N_HUNTER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-03.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_HALFBACK;
 
+	i = 3;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
-			FEMALE, CLASS_N_PRIEST, 3 );
-	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
+	new_mbr( ls_mbr[i], "+-==CECILE=====X", 'C', race,
+			FEMALE, CLASS_N_PRIEST, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-04.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 4;
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
-			MALE, CLASS_N_THIEF, 4 );
-	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
+	new_mbr( ls_mbr[i], "m-o HALLE  <<<)=", 'H', race,
+			MALE, CLASS_N_THIEF, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-05.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
+	i = 5;
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
-			FEMALE, CLASS_N_WIZARD, 5 );
-	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
+	new_mbr( ls_mbr[i], "O>==BEAUT====---", 'U', race,
+			FEMALE, CLASS_N_WIZARD, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-06.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
+	i = 6;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
-			MALE, CLASS_N_MONK, 6 );
-	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
+	new_mbr( ls_mbr[i], "====GOKOU=======", 'G', race,
+			MALE, CLASS_N_MONK, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-07.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 7;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
-			FEMALE, CLASS_N_SUMMONER, 7 );
-	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.bmp",
+	new_mbr( ls_mbr[i], "----EYE-------|===", 'Y', race,
+			FEMALE, CLASS_N_SUMMONER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-08.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
 	/* item */
 
@@ -459,69 +477,85 @@ void	init_party_debug( void )
 	item_kind_dat_t	sub_kind;
 	long	i;
 
+	i = 0;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
-			MALE, CLASS_N_NINJA, 0 );
-	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.bmp",
+	new_mbr( ls_mbr[i], "<///BLADE//}===o", 'B', race,
+			MALE, CLASS_N_NINJA, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-01.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 1;
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
-			MALE, CLASS_N_FIGHTER, 1 );
-	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.bmp",
+	new_mbr( ls_mbr[i], ")(==DRANK======>", 'D', race,
+			MALE, CLASS_N_FIGHTER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-02.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 2;
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
-			MALE, CLASS_N_HUNTER, 2 );
-	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
+	new_mbr( ls_mbr[i], "<---ELSIE----<<<", 'E', race,
+			MALE, CLASS_N_HUNTER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-03.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_HALFBACK;
 
+	i = 3;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
-			FEMALE, CLASS_N_PRIEST, 3 );
-	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
+	new_mbr( ls_mbr[i], "+-==CECILE=====X", 'C', race,
+			FEMALE, CLASS_N_PRIEST, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-04.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 4;
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
-			MALE, CLASS_N_THIEF, 4 );
-	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
+	new_mbr( ls_mbr[i], "m-o HALLE  <<<)=", 'H', race,
+			MALE, CLASS_N_THIEF, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-05.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
+	i = 5;
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
-			FEMALE, CLASS_N_WIZARD, 5 );
-	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
+	new_mbr( ls_mbr[i], "O>==BEAUT====---", 'U', race,
+			FEMALE, CLASS_N_WIZARD, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-06.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
+	i = 6;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
-			MALE, CLASS_N_MONK, 6 );
-	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
+	new_mbr( ls_mbr[i], "====GOKOU=======", 'G', race,
+			MALE, CLASS_N_MONK, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-07.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
+	i = 7;
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_BYTE );
-	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
-			FEMALE, CLASS_N_SUMMONER, 7 );
-	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.bmp",
+	new_mbr( ls_mbr[i], "----EYE-------|===", 'Y', race,
+			FEMALE, CLASS_N_SUMMONER, i );
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-08.bmp",
 			FILE_NAME_MAX_LEN );
+	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
 	/* ã */
 
@@ -1220,6 +1254,7 @@ void	new_mbr(
 	str_nz_cpy( mbr->name, name, MBR_NAME_MAX_BYTE );
 	mbr->mbr_n = MBR_N_NOT_JOIN;
 	mbr->ls_mbr_n = ls_mbr_n;
+	mbr->position_kind = POSITION_KIND_FORWARD;
 	mbr->face.mjr = FACE_MJR_MBR;
 	mbr->face.mnr = face;
 	mbr->face.mjr_org = FACE_MJR_MBR;
@@ -1617,11 +1652,11 @@ void	appear_party( void )
 
 	flg_force = FALSE;
 	do {
-		if( appear_party_randm() )
+		if( appear_party_sub_randm() )
 			break;
-		if( appear_party_srch() )
+		if( appear_party_sub_srch() )
 			break;
-		appear_party_force();
+		appear_party_sub_force();
 		flg_force = TRUE;
 	} while( 0 );
 
@@ -1642,7 +1677,7 @@ void	appear_party( void )
 * return : ?
 ***************************************************************/
 
-bool_t	appear_party_randm( void )
+bool_t	appear_party_sub_randm( void )
 {
 	square_t	*sq;
 	long	i, n;
@@ -1694,7 +1729,7 @@ bool_t	appear_party_randm( void )
 * return : ?
 ***************************************************************/
 
-bool_t	appear_party_srch( void )
+bool_t	appear_party_sub_srch( void )
 {
 	square_t	*sq;
 	long	randm_x, randm_y;
@@ -1764,7 +1799,7 @@ bool_t	appear_party_srch( void )
 * Сޥåפ˽и (Ū)
 ***************************************************************/
 
-void	appear_party_force( void )
+void	appear_party_sub_force( void )
 {
 	long	x, y;
 	long	n;
@@ -1790,6 +1825,111 @@ void	appear_party_force( void )
 	reset_mbr_dir();
 }
 
+/***************************************************************
+* Сޥåפ˽и (ûΥ)
+* long bx :  x ɸ
+* long by :  y ɸ
+* return : ?
+***************************************************************/
+
+bool_t	appear_party_short( long bx, long by )
+{
+	bool_t	flg_success;
+	long	pre_x[MBR_MAX_N], pre_y[MBR_MAX_N];
+	long	n;
+
+	flg_success = FALSE;
+
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		pre_x[n] = party.mbr[n]->x;
+		pre_y[n] = party.mbr[n]->y;
+
+		lost_trgt( party.mbr[n] );
+		clr_chr_trgt_act( party.mbr[n], FALSE );
+	}
+
+	release_all_mbr();
+	clr_map_all_mbr();
+
+	if( appear_party_sub_area( bx, by ) ){
+		flg_success = TRUE;
+	} else {
+		for( n = 0; n < MBR_MAX_N; n++ ){
+			party.mbr[n]->x = pre_x[n];
+			party.mbr[n]->y = pre_y[n];
+		}
+	}
+
+	set_map_all_mbr();
+	appear_all_pet();
+
+	next_pos_square( 0 );
+	scroll_center_appear_party();
+	set_flg_find_all_mnstr();
+
+	redraw_all();
+
+	return flg_success;
+}
+
+/***************************************************************
+* Сޥåפ˽и (Ʊꥢ)
+* long bx :  x ɸ
+* long by :  y ɸ
+* return : ?
+***************************************************************/
+
+bool_t	appear_party_sub_area( long bx, long by )
+{
+	long	ax, ay;
+	square_t	*sq;
+	long	i, n;
+
+	sq = get_square_mbr();
+	if( sq == NULL )
+		return FALSE;
+
+	ax = bx / AREA_MAX_X * AREA_MAX_X;
+	ay = by / AREA_MAX_Y * AREA_MAX_Y;
+
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		sq->x = ax + (1 + randm( AREA_MAX_X - 2));
+		sq->y = ay + (1 + randm( AREA_MAX_Y - 2));
+		sq->pre_x = sq->x;
+		sq->pre_y = sq->y;
+
+		for( n = 0; n < MBR_MAX_N; n++ ){
+			long	nx, ny;
+
+			if( chk_flg_or( party.mbr[n]->stat,
+					FLG_STAT_NOT_EXIST
+					| FLG_STAT_DEAD ) ){
+				continue;
+			}
+
+			get_square_mbr_abs_pos( n, &nx, &ny );
+			party.mbr[n]->x = nx;
+			party.mbr[n]->y = ny;
+			party.mbr[n]->pre_x = nx;
+			party.mbr[n]->pre_y = ny;
+
+			if( !can_move_chr( party.mbr[n], nx, ny ) ){
+				/* ֤˰ưʤ */
+				break;
+			}
+		}
+		if( n >= MBR_MAX_N ){
+			/* ư褿 */
+			reset_mbr_dir();
+			return TRUE;
+		}
+	}
+
+	/* ưʤä */
+	reset_mbr_dir();
+	return FALSE;
+}
+
 /***************************************************************
 * Сޥåפ˽и (饹ܥ)
 ***************************************************************/
@@ -2233,6 +2373,9 @@ void	mbr_peep_door( mbr_t *mbr, long dr_n )
 void	clr_party_act( void )
 {
 	party.act.kind = ACT_KIND_NULL;
+	str_nz_cpy( party.act.msg, "", ACT_MSG_MAX_BYTE );
+
+	draw_misc_stat();
 }
 
 /**/
@@ -2272,31 +2415,24 @@ void	not_join_mbr( long ls_mbr_n, long mbr_n )
 
 void	collect_gold( mbr_t *mbr )
 {
-	bool_t	flg_force;
-	gold_t	gold, res_price;
+	gold_t	gold;
 	long	i;
 
 	if( mbr == NULL )
 		return;
 
-	/* Ѥ GOLD ϵݽʤ */
+	/* ڥåȤ NPC ϵ */
 
-	res_price = get_price_temple_resurrection( mbr );
-	flg_force = FALSE;
-	if( chk_flg( mbr->stat, FLG_STAT_DEAD )
-			&& (get_chr_gold( mbr ) < res_price)
-			&& (mbr->fx_data.friend_turn > 0) ){
-		flg_force = TRUE;
+	if( !is_mbr( mbr ) ){
+		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD, mbr->name );
+		return;
 	}
 
 	/* GOLD Τ */
 
 	if( mbr->fx_data.friend_turn > 0 ){
-		if( !flg_force ){
-			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-					mbr->name );
-			return;
-		}
+		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD, mbr->name );
+		return;
 	}
 
 	gold = 0;
@@ -2307,11 +2443,9 @@ void	collect_gold( mbr_t *mbr )
 		/* GOLD Τ */
 
 		if( party.mbr[i]->fx_data.friend_turn > 0 ){
-			if( !flg_force ){
-				print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-						party.mbr[i]->name );
-				continue;
-			}
+			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+					party.mbr[i]->name );
+			continue;
 		}
 
 		gold += get_chr_gold( party.mbr[i] );
@@ -2327,20 +2461,9 @@ void	collect_gold( mbr_t *mbr )
 
 void	divide_gold( void )
 {
-	bool_t	flg_force;
 	gold_t	sum, gold;
 	long	i, n, mod_n;
 
-	/* Ѥ GOLD ϵݽʤ */
-
-	flg_force = FALSE;
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( chk_flg( party.mbr[i]->stat, FLG_STAT_DEAD ) ){
-			flg_force = TRUE;
-			break;
-		}
-	}
-
 	mod_n = 0;
 	n = 0;
 	sum = 0;
@@ -2351,11 +2474,9 @@ void	divide_gold( void )
 		/* GOLD Τ */
 
 		if( party.mbr[i]->fx_data.friend_turn > 0 ){
-			if( !flg_force ){
-				print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-						party.mbr[i]->name );
-				continue;
-			}
+			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+					party.mbr[i]->name );
+			continue;
 		}
 
 		sum += get_chr_gold( party.mbr[i] );
@@ -2372,8 +2493,7 @@ void	divide_gold( void )
 		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 		if( party.mbr[i]->fx_data.friend_turn > 0 )
-			if( !flg_force )
-				continue;
+			continue;
 
 		add_chr_gold( party.mbr[i], gold );
 		sum -= gold;
@@ -2401,52 +2521,48 @@ void	give_gold( mbr_t *mbr_from, mbr_t *mbr_to, gold_t gold )
 	/* Ѥ GOLD ϵݽʤ */
 
 	res_price = get_price_temple_resurrection( mbr_to );
-	if( chk_flg( mbr_to->stat, FLG_STAT_DEAD )
-			&& (get_chr_gold( mbr_to ) < res_price)
-			&& (mbr_to->fx_data.friend_turn > 0) ){
+	if( (get_chr_gold( mbr_to ) + gold <= res_price)
+			&& chk_flg( mbr_to->stat, FLG_STAT_DEAD ) ){
 		flg_force = TRUE;
 	}
 
 	/* 夯餤 GOLD ϵݤʤ */
 
 	inn_price = get_price_inn( FALSE );
-	do {
-		if( mbr_from->fx_data.friend_turn > 0 )
-			break;
-		if( mbr_to->fx_data.friend_turn <= 0 )
-			break;
-		if( get_chr_gold( mbr_to ) + gold > inn_price )
-			break;
-
+	if( get_chr_gold( mbr_to ) + gold <= inn_price )
 		flg_force = TRUE;
-		break;
-	} while( 0 );
 
 	/* 礬ɤå */
 
 	do {
-		if( flg_force )
-			break;
-		if( mbr_from->fx_data.friend_turn <= 0 )
-			if( mbr_to->fx_data.friend_turn <= 0 )
+		if( !flg_force ){
+			if( mbr_from->fx_data.friend_turn > 0 )
 				break;
+			if( mbr_to->fx_data.friend_turn > 0 )
+				break;
+			if( is_pet( mbr_from ) )
+				break;
+			if( !is_mbr( mbr_to ) )
+				break;
+		}
 
-		/* GOLD Τ */
+		max = GOLD_MAX - get_chr_gold( mbr_to );
+		if( gold > max )
+			gold = max;
 
-		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+		add_chr_gold( mbr_from, -gold );
+		add_chr_gold( mbr_to, +gold );
+
+		print_msg( FLG_NULL, MSG_GIVE_GOLD,
+				mbr_from->name, fmt_gold( gold ),
 				mbr_to->name );
+
 		return;
 	} while( 0 );
 
-	max = GOLD_MAX - get_chr_gold( mbr_to );
-	if( gold > max )
-		gold = max;
+	/* GOLD Τ */
 
-	add_chr_gold( mbr_from, -gold );
-	add_chr_gold( mbr_to, +gold );
-
-	print_msg( FLG_NULL, MSG_GIVE_GOLD,
-			mbr_from->name, fmt_gold( gold ), mbr_to->name );
+	print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD, mbr_to->name );
 }
 
 /**/
@@ -2622,12 +2738,19 @@ void	exp_party( long exp, bool_t flg_set_max, bool_t flg_draw )
 	/* ڥå */
 
 	for( i = 0; i < PET_MAX_N; i++ ){
+		bool_t	flg_print_lev;
+
 		if( pet[i] == NULL )
 			continue;
 		if( chk_flg_or( pet[i]->stat, flg ) )
 			continue;
 
-		exp_chr( pet[i], exp_add, flg_set_max, FALSE, TRUE );
+		if( is_client( pet[i] ) )
+			flg_print_lev = FALSE;
+		else
+			flg_print_lev = TRUE;
+
+		exp_chr( pet[i], exp_add, flg_set_max, FALSE, flg_print_lev );
 	}
 }
 
@@ -3424,34 +3547,54 @@ flg_party_t	set_flg_party( flg_party_t flg )
 
 /**/
 
-long	next_mbr( long mbr_n, long add )
+long	next_mbr( long n, long add )
 {
+	pet_t	**pet;
+	long	pet_n;
 	long	i;
 
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		mbr_n += add + MBR_MAX_N;
-		mbr_n %= MBR_MAX_N;
-		if( !chk_flg( party.mbr[mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
-			break;
+	if( add == 0 )
+		return n;
+
+	pet = get_party_pet();
+
+	for( i = 0; i < MBR_MAX_N + PET_MAX_N; i++ ){
+		n += add;
+		n += MBR_MAX_N + PET_MAX_N;
+		n %= MBR_MAX_N + PET_MAX_N;
+
+		if( n < MBR_MAX_N ){
+			if( !chk_flg( party.mbr[n]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+		} else {
+			pet_n = n - MBR_MAX_N;
+			if( (pet[pet_n] != NULL)
+					&& !chk_flg( pet[pet_n]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+		}
 	}
 
-	return mbr_n;
+	return n;
 }
 
 /**/
 
-long	next_ls_mbr( long ls_mbr_n, long add )
+long	next_ls_mbr( long ls_n, long add )
 {
 	long	i;
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
-		ls_mbr_n += add + LS_MBR_MAX_N;
-		ls_mbr_n %= LS_MBR_MAX_N;
-		if( !chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
+		ls_n += add + LS_MBR_MAX_N;
+		ls_n %= LS_MBR_MAX_N;
+		if( !chk_flg( ls_mbr[ls_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 	}
 
-	return ls_mbr_n;
+	return ls_n;
 }
 
 /**/
