@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.24 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: spell-tab.h,v 1.25 2010/05/19 00:32:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -123,6 +123,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/MAG/short_teleport_party",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SHORT_TELEPORT_PARTY, "",
+		cb_menu_spell, (void *)SPELL_KIND_SHORT_TELEPORT_PARTY,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/MAG/teleport_party",
 		"<Branch>",
