@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.202 2009/07/23 12:52:01 bowkenken Exp $
+* $Id: spell.c,v 1.220 2010/08/18 00:43:35 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -33,9 +33,8 @@
 
 /**/
 
-#include	"spell-tab.h"
-
-/**/
+/* ذưʤɤǥ˥塼ꥻåȤ뤫? */
+#define	FLG_RESET_MENU	0
 
 /* ξǵʳȤɤ? */
 #define	FLG_SPELL_SANCTUARY	TRUE
@@ -60,7 +59,11 @@
 #define	SPELL_NIN_RATE	((rate_t)80)
 #define	SPELL_SHA_RESI_DIV_RATE	((rate_t)400)
 
-#define	BAR_LIMIT_LEV	10
+#define	BAR_LIMIT_LEV	30
+
+#define	ACCEL_KEY_REG_SPELL	'X'
+#define	ACCEL_KEY_REG_SPELL_REMARK	'Y'
+#define	ACCEL_KEY_NO_LEARN	'Z'
 
 /**/
 
@@ -68,6 +71,7 @@ static cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
 check_memory_def( check_memory_spell_c_cast_tab )
 
 static mbr_t	*g_sel_mbr;
+static mbr_t	*g_pre_sel_mbr;
 static spell_tab_t	*g_sel_spell;
 check_memory_def( check_memory_spell_c_g_sel_mbr )
 
@@ -87,7 +91,12 @@ check_memory_def( check_memory_spell_c_g_vfx_bgn )
 
 /**/
 
-static mbr_t	*static_cb_menu_sel_spell__pre_sel_mbr;
+reg_spell_t	g_reg_spell[MBR_MAX_N];
+check_memory_def( check_memory_spell_c_g_reg_spell )
+
+/**/
+
+#include	"spell-tab.h"
 
 /**/
 
@@ -96,9 +105,12 @@ void	init_spell( void )
 	long	m;
 	long	k;
 	menu_t	*ls;
-	long	max_len, min_len;
+	long	max_len;
+	int	min_len;
 	long	i;
 
+	g_pre_sel_mbr = NULL;
+
 	for( m = 0; m < LS_MBR_MAX_N; m++ )
 		init_spell_new_mbr( m );
 
@@ -127,6 +139,8 @@ void	init_spell( void )
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		if( ls[i].path[0] == '\0' )
 			break;
+		if( ls[i].arg == NULL )
+			continue;
 
 		max_len = max_l( max_len, str_len_draw(
 				MSG( ls[i].n_msg ) ) );
@@ -152,6 +166,13 @@ void	init_spell( void )
 				MSG( ls[i].n_msg ),
 				tab->mp, tab->hp, tab->gold );
 	}
+
+	for( m = 0; m < MBR_MAX_N; m++ ){
+		g_reg_spell[m].tab = NULL;
+		g_reg_spell[m].extent_kind = EXTENT_KIND_NORMAL;
+		g_reg_spell[m].trgt.kind = TRGT_KIND_NULL;
+		g_reg_spell[m].trgt.p = NULL;
+	}
 }
 
 /***************************************************************
@@ -160,30 +181,31 @@ void	init_spell( void )
 
 void	reset_static_spell( void )
 {
-	long	m;
-
 	/* cast_tab */
 
+#if	FLG_RESET_MENU
 	g_sel_mbr = NULL;
+	g_pre_sel_mbr = NULL;
 	g_sel_spell = NULL;
 
-	for( m = 0; m < LS_MBR_MAX_N; m++ ){
-		long	k;
+	{
+		long	m;
 
-		g_dflt_spell_abl[m] = NULL;
-		for( k = 0; k < ABL_KIND_MAX_N; k++ ){
-			g_dflt_spell[m][k] = NULL;
-			g_dflt_spell_extent[m][k] = NULL;
+		for( m = 0; m < LS_MBR_MAX_N; m++ ){
+			long	k;
+
+			g_dflt_spell_abl[m] = NULL;
+			for( k = 0; k < ABL_KIND_MAX_N; k++ ){
+				g_dflt_spell[m][k] = NULL;
+				g_dflt_spell_extent[m][k] = NULL;
+			}
 		}
 	}
 	g_sel_spell_abl = ABL_KIND_HP;
+#endif
 
-	g_vfx_n = 0;
+	/* g_vfx_n = 0; */
 	/* g_vfx_bgn, g_vfx_end */;
-
-	/**/
-
-	static_cb_menu_sel_spell__pre_sel_mbr = NULL;
 }
 
 /**/
@@ -263,7 +285,6 @@ void	init_spell_dflt( void )
 
 	m = LS_MBR_N_BEAUT;
 	cast_tab[m][SPELL_KIND_LIGHT].flg_cast = TRUE;
-	cast_tab[m][SPELL_KIND_STORE_LIGHT].flg_cast = TRUE;
 }
 
 /**/
@@ -281,18 +302,29 @@ void	init_spell_nin( void )
 
 /**/
 
+void	reset_spell( void )
+{
+	long	m;
+
+	for( m = 0; m < MBR_MAX_N; m++ ){
+		g_reg_spell[m].tab = NULL;
+		g_reg_spell[m].extent_kind = EXTENT_KIND_NORMAL;
+		g_reg_spell[m].trgt.kind = TRGT_KIND_NULL;
+		g_reg_spell[m].trgt.p = NULL;
+	}
+}
+
+/**/
+
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
-	mbr_t	*pre_sel_mbr;
 	pos_t	*crsr;
 	bool_t	flg_sel_mbr;
 	char	*str_goto;
 
-	pre_sel_mbr = static_cb_menu_sel_spell__pre_sel_mbr;
-
 	set_menu_dflt_main( *pp );
 
-	crsr = get_crsr();
+	crsr = get_main_crsr();
 	g_sel_mbr = get_mbr( crsr->x, crsr->y );
 	if( g_sel_mbr == NULL )
 		flg_sel_mbr = TRUE;
@@ -303,7 +335,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		if( flg_sel_mbr ){
 			char	*str;
 
-			g_sel_mbr = pre_sel_mbr;
+			g_sel_mbr = g_pre_sel_mbr;
 
 			str = exec_menu_sel_mbr( &g_sel_mbr, NULL,
 					FALSE, FALSE );
@@ -313,8 +345,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		if( g_sel_mbr == NULL )
 			return STR_MENU_ERR;
 
-		pre_sel_mbr = g_sel_mbr;
-		static_cb_menu_sel_spell__pre_sel_mbr = pre_sel_mbr;
+		g_pre_sel_mbr = g_sel_mbr;
 
 		str_goto = menu_sel_spell( g_sel_mbr );
 		if( str_goto == NULL )
@@ -337,6 +368,7 @@ char	*menu_sel_spell( mbr_t *mbr )
 	unsigned char	key;
 	bool_t	flg;
 	bool_t	flg_learn;
+	reg_spell_t	*reg;
 	long	i;
 
 	if( mbr == NULL )
@@ -350,6 +382,8 @@ char	*menu_sel_spell( mbr_t *mbr )
 	ls = ls_menu_spell;
 	clr_flg_menu( ls, NULL, FLG_MENU_ALL );
 
+	reg = get_reg_spell( mbr->mbr_n );
+
 	flg_learn = FALSE;
 	key = 'A';
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
@@ -361,7 +395,34 @@ char	*menu_sel_spell( mbr_t *mbr )
 			key = 'A';
 			continue;
 		}
-		if( ls[i].accel_key == 'Z' ){
+		if( ls[i].accel_key == ACCEL_KEY_REG_SPELL ){
+			if( (reg != NULL) && (reg->tab != NULL)
+					&& (reg->trgt.p != NULL) ){
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL,
+						reg->tab->name );
+			} else {
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL_NULL );
+			}
+			continue;
+		}
+		if( ls[i].accel_key == ACCEL_KEY_REG_SPELL_REMARK ){
+			if( (reg != NULL) && (reg->tab != NULL) ){
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL_REMARK,
+						reg->tab->name );
+			} else {
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL_NULL );
+			}
+			continue;
+		}
+		if( ls[i].accel_key == ACCEL_KEY_NO_LEARN ){
 			if( flg_learn )
 				ls[i].flg |= FLG_MENU_HIDDEN;
 			else
@@ -454,6 +515,133 @@ char	*menu_sel_spell( mbr_t *mbr )
 
 /**/
 
+char	*cb_menu_reg_spell( menu_t **pp, menu_t **dflt )
+{
+	mbr_t	*mbr;
+	long	mbr_n;
+	void	*p;
+
+	mbr = g_sel_mbr;
+	if( mbr == NULL )
+		return STR_MENU_CANCEL;
+
+	mbr_n = mbr->mbr_n;
+	if( mbr_n < 0 )
+		return STR_MENU_CANCEL;
+	if( mbr_n >= MBR_MAX_N )
+		return STR_MENU_CANCEL;
+
+	p = g_reg_spell[mbr_n].trgt.p;
+	if( p == NULL )
+		return STR_MENU_CANCEL;
+
+	if( g_reg_spell[mbr_n].tab == NULL )
+		return STR_MENU_CANCEL;
+	if( g_reg_spell[mbr_n].trgt.kind == TRGT_KIND_NULL )
+		return STR_MENU_CANCEL;
+
+	/* ˥塼ΥǥեȤ */
+
+	g_dflt_spell_abl[mbr->ls_mbr_n] = *pp;
+
+	/* åȤޡ */
+
+	switch( g_reg_spell[mbr_n].trgt.kind ){
+	case TRGT_KIND_NULL:
+	case TRGT_KIND_AUTO:
+	case TRGT_KIND_MAX_N:
+		return STR_MENU_ERR;
+	case TRGT_KIND_MBR:
+		mark_mbr( mbr, (mbr_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_MNSTR:
+		mark_mnstr( mbr, (mnstr_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_MNSTR_NULL:
+		mark_mnstr_null( mbr,
+				g_reg_spell[mbr_n].trgt.x,
+				g_reg_spell[mbr_n].trgt.y,
+				DIST_FAR );
+		break;
+	case TRGT_KIND_POS:
+		mark_pos( mbr,
+				g_reg_spell[mbr_n].trgt.x,
+				g_reg_spell[mbr_n].trgt.y,
+				DIST_FAR );
+		break;
+	case TRGT_KIND_ITEM:
+		mark_item( mbr, (item_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_DOOR:
+		mark_door( mbr, (door_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_TRAP:
+		mark_trap( mbr, (trap_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_QUEUE:
+		return STR_MENU_ERR;
+	case TRGT_KIND_SQUARE:
+		mark_square( mbr );
+		break;
+	}
+
+	/*  */
+
+	set_chr_act( mbr, ACT_KIND_SPELL,
+			g_reg_spell[mbr_n].tab, NULL,
+			g_reg_spell[mbr_n].extent_kind, 0 );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_reg_spell_remark( menu_t **pp, menu_t **dflt )
+{
+	mbr_t	*mbr;
+	long	mbr_n;
+
+	mbr = g_sel_mbr;
+	if( mbr == NULL )
+		return STR_MENU_CANCEL;
+
+	mbr_n = mbr->mbr_n;
+	if( mbr_n < 0 )
+		return STR_MENU_CANCEL;
+	if( mbr_n >= MBR_MAX_N )
+		return STR_MENU_CANCEL;
+
+	if( g_reg_spell[mbr_n].tab == NULL )
+		return STR_MENU_CANCEL;
+	if( g_reg_spell[mbr_n].trgt.kind == TRGT_KIND_NULL )
+		return STR_MENU_CANCEL;
+
+	/* ˥塼ΥǥեȤ */
+
+	g_dflt_spell_abl[mbr->ls_mbr_n] = *pp;
+
+	/* åȤޡ */
+
+	if( get_spell_flg_trgt( g_sel_spell,
+			g_reg_spell[mbr_n].extent_kind ) ){
+		char	*str_goto;
+
+		str_goto = menu_spell_trgt( g_sel_mbr );
+		if( str_goto != NULL )
+			return str_goto;
+	}
+
+	/*  */
+
+	set_chr_act( mbr, ACT_KIND_SPELL,
+			g_reg_spell[mbr_n].tab, NULL,
+			g_reg_spell[mbr_n].extent_kind, 0 );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_dflt_spell_mag( menu_t **pp, menu_t **dflt )
 {
 	return menu_dflt_spell( pp, dflt, ABL_KIND_MAG );
@@ -542,13 +730,19 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 
 	if( !chk_can_chr_cast_lev( g_sel_mbr, g_sel_spell->kind ) ){
+		curs_attrset_chr( g_sel_mbr, -1, FALSE );
 		print_msg( FLG_NULL, MSG_ERR_MENU_SPELL_LEV,
 				g_sel_mbr->name );
+		curs_attrset_dflt();
+
 		return STR_MENU_CANCEL;
 	}
 
 	if( !chk_last_boss_can_spell( g_sel_spell->kind ) ){
+		curs_attrset_chr( g_sel_mbr, -1, FALSE );
 		print_msg( FLG_NULL, MSG_ERR_MENU_SPELL_LAST_BOSS );
+		curs_attrset_dflt();
+
 		return STR_MENU_CANCEL;
 	}
 
@@ -595,7 +789,6 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 {
 	extent_kind_t	ex;
-	bool_t	flg_trgt;
 
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
@@ -606,22 +799,7 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 	ex = (extent_kind_t)(long)((*pp)->arg);
 
-	flg_trgt = FALSE;
-	if( g_sel_spell->flg_trgt )
-		flg_trgt = TRUE;
-	do {
-		if( g_sel_spell->kind < SPELL_KIND_BAR_MIN_N )
-			break;
-		if( g_sel_spell->kind > SPELL_KIND_BAR_MAX_N )
-			break;
-		if( ex != EXTENT_KIND_NORMAL )
-			break;
-
-		flg_trgt = FALSE;
-		break;
-	} while( 0 );
-
-	if( flg_trgt ){
+	if( get_spell_flg_trgt( g_sel_spell, ex ) ){
 		char	*str_goto;
 
 		str_goto = menu_spell_trgt( g_sel_mbr );
@@ -638,6 +816,27 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 /**/
 
+bool_t	get_spell_flg_trgt( spell_tab_t *tab, extent_kind_t ex )
+{
+	if( tab == NULL )
+		return FALSE;
+
+	do {
+		if( tab->kind < SPELL_KIND_BAR_MIN_N )
+			break;
+		if( tab->kind > SPELL_KIND_BAR_MAX_N )
+			break;
+		if( ex != EXTENT_KIND_NORMAL )
+			break;
+
+		return FALSE;
+	} while( 0 );
+
+	return( tab->flg_trgt );
+}
+
+/**/
+
 char	*menu_spell_trgt( mbr_t *mbr )
 {
 	pos_t	*crsr;
@@ -654,7 +853,7 @@ char	*menu_spell_trgt( mbr_t *mbr )
 
 	/* ΥåȤ˥ư */
 
-	crsr = get_crsr();
+	crsr = get_main_crsr();
 	if( crsr == NULL )
 		return STR_MENU_ERR;
 	if( mbr->trgt.kind != TRGT_KIND_SQUARE ){
@@ -756,6 +955,11 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	if( !chk_last_boss_can_spell( tab->kind ) )
 		return;
 
+	if( is_mbr( chr ) ){
+		set_reg_spell( chr->mbr_n, tab,
+				(extent_kind_t)(chr->act.n), chr->trgt );
+	}
+
 	hp = tab->hp;
 	mp = tab->mp;
 	resi = tab->resi_down;
@@ -931,6 +1135,20 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	fx_cast_spell( chr, tab );
 
 	set_vfx_attr( &prev_attr );
+
+	/* פ */
+
+	if( is_mbr( chr ) ){
+		update_playing_report_using_spell(
+				chr->ls_mbr_n, tab->kind );
+	}
+	if( chr->trgt.kind == TRGT_KIND_MBR){
+		mbr_t	*mbr;
+
+		mbr = (mbr_t *)(chr->trgt.p);
+		update_playing_report_used_spell(
+				mbr->ls_mbr_n, tab->kind );
+	}
 }
 
 /**/
@@ -1061,9 +1279,11 @@ void	chr_cast_spell_blast(
 {
 	blast_t	*blast;
 	char	*blast_str;
+	gui_vfx_t	*gui_vfx;
 	long	nx, ny;
 	long	xx, yy;
 	bool_t	flg_actual;
+	bool_t	flg_pet;
 	chr_kind_t	kind;
 	chr_t	*trgt_chr;
 
@@ -1081,6 +1301,11 @@ void	chr_cast_spell_blast(
 	else
 		kind = CHR_KIND_NULL;
 
+	if( is_pet( (pet_t *)(chr->trgt.p) ) )
+		flg_pet = TRUE;
+	else
+		flg_pet = FALSE;
+
 	if( is_mnstr( chr ) ){
 		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) ){
 			call_game_sound_play(
@@ -1093,9 +1318,12 @@ void	chr_cast_spell_blast(
 		}
 	}
 
+	/* GUI */
+	gui_vfx = alloc_gui_vfx_blast( BLAST_KIND_STD );
+
 	blast = get_blast_spell( tab->kind );
 	blast_str = get_spell_vfx_str( tab->kind );
-	draw_blast( kind, x, y, blast, blast_str );
+	draw_blast( kind, x, y, blast, gui_vfx, blast_str );
 	if( clip_draw_pos( x, y ) )
 		wait_clock( ANIM_FRAME_N_BLAST_STD );
 
@@ -1134,6 +1362,8 @@ void	chr_cast_spell_blast(
 				if( p == chr )
 					continue;
 
+				if( flg_pet )
+					break;
 				if( flg_actual )
 					break;
 				if( is_mnstr( chr ) )
@@ -1173,6 +1403,8 @@ void	chr_cast_spell_blast(
 				trgt_chr->work.flg |= FLG_WORK_BLAST_END;
 			}
 
+			draw_blast( kind, x, y, blast,
+					gui_vfx, blast_str );
 			draw_map( xx, yy, 1, 1 );
 
 			chr_cast_spell_sub( chr, flg_item, tab, rate,
@@ -1183,10 +1415,15 @@ void	chr_cast_spell_blast(
 	end_sync_vfx_num();
 	clr_all_chr_flg_blast();
 
-	draw_blast( kind, x, y, blast, blast_str );
+	draw_blast( kind, x, y, blast, gui_vfx, blast_str );
 	if( clip_draw_pos( x, y ) )
 		wait_clock( ANIM_FRAME_N_BLAST_STD );
 
+	/* GUI */
+	clr_gui_vfx_all();
+	free_gui_vfx( gui_vfx );
+	call_pcg_dun_redraw( TRUE );
+
 	xx = x - (blast->xr / 2);
 	yy = y - blast->yr;
 	nx = (blast->xl + str_len_draw( blast_str )) / 2;
@@ -1661,8 +1898,10 @@ void	chr_cast_spell_sub(
 
 	/* ɸ˻̤äƤ뤫å */
 
-	if( !flg_chr || (trgt_kind == TRGT_KIND_MNSTR_NULL)
-			||  (trgt_kind != TRGT_KIND_POS) ){
+	if( trgt_kind == TRGT_KIND_DOOR ){
+		;/**/
+	} else if( !flg_chr || (trgt_kind == TRGT_KIND_MNSTR_NULL)
+			||  (trgt_kind == TRGT_KIND_POS) ){
 		pos_t	pos1, pos2;
 
 		pos1.x = chr->x;
@@ -1786,6 +2025,9 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_STORE_LIGHT:
 		fx_store_light( chr );
 		break;
+	case SPELL_KIND_SHORT_TELEPORT_PARTY:
+		fx_short_teleport_party( chr->x, chr->y );
+		break;
 	case SPELL_KIND_TELEPORT_PARTY:
 		fx_teleport_party_charge();
 		break;
@@ -1812,13 +2054,9 @@ void	chr_cast_spell_sub(
 			fx_disarm_trap( get_trap( x, y ), chr );
 		}
 		break;
-	case SPELL_KIND_DISPEL_MAGIC:
-/*@@@*/
-		break;
-	case SPELL_KIND_MIRROR_IMAGE:
-/*@@@*/
 	case SPELL_KIND_ANIMATE_OBJECTS:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_SHELTER:
 		fx_shelter( x, y );
@@ -1839,8 +2077,11 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_ANALYZE_DWEOMER:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_DETECT_MAGIC:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_DETECT_ITEM:
 		fx_detect_item( chr );
@@ -1860,6 +2101,7 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_FEATHER_FALL:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_VANISH:
 		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
@@ -1870,13 +2112,24 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_PASSWALL:
 		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
+	case SPELL_KIND_DISPEL_MAGIC:
+/*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
+	case SPELL_KIND_MIRROR_IMAGE:
+/*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_POLYMORPH_OTHER:
 		fx_polymorph( (chr_t *)p );
 		break;
 	case SPELL_KIND_POLYMORPH_SELF:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_STEALTH:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_MAG_MAX_N:
 		break;
@@ -1925,12 +2178,14 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_STONESKIN:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_IRON_BODY:
 		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_SPELL_RESISTANCE:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_COUNTER_MAGIC:
 		fx_std( (chr_t *)p, FX_KIND_COUNTER_MAGIC );
@@ -2011,8 +2266,11 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_HUNGER:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
+		break;
 	case SPELL_KIND_CANCELLATION:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_ENC_MAX_N:
 		break;
@@ -2045,9 +2303,11 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_SUMMON_RANDOM:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_CREATE_UNDEAD:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_DISMISSAL:
 		fx_dismissal( (chr_t *)p );
@@ -2072,12 +2332,14 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_CURE_MP:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_TRANSFER_MP:
 		fx_transfer_mp( (chr_t *)p, tab, rate );
 		break;
 	case SPELL_KIND_REGENERATION:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_RESTORE_EXPERIENCE:
 		fx_cure_exp( (chr_t *)p );
@@ -2123,6 +2385,7 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_PROTECTION:
 /*@@@*/
+		print_msg( FLG_NULL, MSG_INCOMPLETE );
 		break;
 	case SPELL_KIND_RESIST_PHYSICAL:
 		fx_resi( (chr_t *)p, FX_KIND_RESI_KNOC );
@@ -2157,7 +2420,7 @@ void	chr_cast_spell_sub(
 		fx_dispel_undead( chr, trgt_kind, (chr_t *)p, rate );
 		break;
 	case SPELL_KIND_ESCAPE:
-		fx_teleport_party_charge();
+		fx_escape( chr->x, chr->y );
 		break;
 	case SPELL_KIND_SANCTUARY:
 		fx_sanctuary( chr, ABL_KIND_PRI );
@@ -2234,6 +2497,9 @@ void	chr_cast_spell_sub(
 		fx_summon_monster( chr, MNSTR_KIND_SHADE, 1,
 				DISMISSAL_TURN_ELEMENTAL );
 		break;
+	case SPELL_KIND_DISMISSAL_ELEMENTAL:
+		fx_dismissal( (chr_t *)p );
+		break;
 	case SPELL_KIND_SHA_MAX_N:
 		break;
 /* BAR */
@@ -2381,6 +2647,48 @@ void	counter_magic(
 
 /**/
 
+reg_spell_t	*get_reg_spell( long mbr_n )
+{
+	if( mbr_n < 0 )
+		return NULL;
+	if( mbr_n >= MBR_MAX_N )
+		return NULL;
+
+	return &(g_reg_spell[mbr_n]);
+}
+
+/**/
+
+void	set_reg_spell(
+	long mbr_n,
+	spell_tab_t *tab,
+	extent_kind_t extent_kind,
+	trgt_t trgt
+)
+{
+	if( mbr_n < 0 )
+		return;
+	if( mbr_n >= MBR_MAX_N )
+		return;
+
+	g_reg_spell[mbr_n].tab = tab;
+	g_reg_spell[mbr_n].extent_kind = extent_kind;
+	g_reg_spell[mbr_n].trgt = trgt;
+}
+
+/**/
+
+void	lost_trgt_reg_spell( void *p )
+{
+	long	m;
+
+	for( m = 0; m < MBR_MAX_N; m++ )
+		if( g_reg_spell[m].trgt.p == p )
+			g_reg_spell[m].trgt.p = NULL;
+}
+
+/**/
+
 bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item )
 {
 	abl_kind_t	o_abl, o_sub_abl;
@@ -2432,14 +2740,13 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
 	case SPELL_KIND_STORE_LIGHT:
+	case SPELL_KIND_SHORT_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT:
 	case SPELL_KIND_RECALL:
 	case SPELL_KIND_KNOCK:
 	case SPELL_KIND_LOCK:
 	case SPELL_KIND_DISARM_TRAP:
-	case SPELL_KIND_DISPEL_MAGIC:
-	case SPELL_KIND_MIRROR_IMAGE:
 	case SPELL_KIND_ANIMATE_OBJECTS:
 	case SPELL_KIND_SHELTER:
 	case SPELL_KIND_CREATE_FOOD:
@@ -2479,6 +2786,8 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 		if( (trgt != TRGT_KIND_MBR) && (trgt != TRGT_KIND_MNSTR) )
 			return FALSE;
 		break;
+	case SPELL_KIND_DISPEL_MAGIC:
+	case SPELL_KIND_MIRROR_IMAGE:
 	case SPELL_KIND_POLYMORPH_OTHER:
 	case SPELL_KIND_POLYMORPH_SELF:
 	case SPELL_KIND_STEALTH:
@@ -2651,6 +2960,10 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_SUMMON_WILL_O_WISP:
 	case SPELL_KIND_SUMMON_SHADE:
 		break;
+	case SPELL_KIND_DISMISSAL_ELEMENTAL:
+		if( trgt != TRGT_KIND_MNSTR )
+			return FALSE;
+		break;
 	case SPELL_KIND_SHA_MAX_N:
 		break;
 /* BAR */
@@ -3338,6 +3651,7 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
 	case SPELL_KIND_STORE_LIGHT:
+	case SPELL_KIND_SHORT_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT:
 	case SPELL_KIND_RECALL:
@@ -3348,8 +3662,6 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 		return "+^";
 	case SPELL_KIND_DISARM_TRAP:
 		return "^*";
-	case SPELL_KIND_DISPEL_MAGIC:
-	case SPELL_KIND_MIRROR_IMAGE:
 	case SPELL_KIND_ANIMATE_OBJECTS:
 		break;
 	case SPELL_KIND_SHELTER:
@@ -3370,6 +3682,8 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 	case SPELL_KIND_VANISH:
 	case SPELL_KIND_DARKVISION:
 	case SPELL_KIND_PASSWALL:
+	case SPELL_KIND_DISPEL_MAGIC:
+	case SPELL_KIND_MIRROR_IMAGE:
 	case SPELL_KIND_POLYMORPH_OTHER:
 	case SPELL_KIND_POLYMORPH_SELF:
 	case SPELL_KIND_STEALTH:
@@ -3530,6 +3844,8 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 	case SPELL_KIND_SUMMON_WILL_O_WISP:
 	case SPELL_KIND_SUMMON_SHADE:
 		break;
+	case SPELL_KIND_DISMISSAL_ELEMENTAL:
+		return "><";
 	case SPELL_KIND_SHA_MAX_N:
 		break;
 /* BAR */
@@ -3686,6 +4002,8 @@ void	check_memory_spell_c( void )
 			"spell.c: g_vfx_n" );
 	check_memory( check_memory_spell_c_g_vfx_bgn,
 			"spell.c: g_vfx_bgn" );
+	check_memory( check_memory_spell_c_g_reg_spell,
+			"spell.c: g_reg_spell" );
 }
 
 /**/
