@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.31 2010/05/19 00:32:53 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.32 2010/08/31 11:21:32 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -1945,6 +1945,15 @@ menu_t	ls_menu_pet_shop[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
+	{
+		"/pet shop/data",
+		"<OpenWinItem>",
+		'D',
+		"",
+		N_MSG_MENU_PET_SHOP_DATA, "",
+		cb_menu_pet_shop_data, NULL,
+		FLG_NULL,
+	},
 	{
 		"/pet shop/buy",
 		"<Branch>",
