@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.161 2010/05/29 14:37:00 bowkenken Exp $
+* $Id: town.c,v 1.162 2010/08/05 00:08:46 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -2036,6 +2036,9 @@ void	stay_inn( stay_inn_kind_t kind )
 	fx_t	*fx;
 	long	i, j;
 
+	/* פ */
+	update_playing_report_staying_inn_party( kind );
+
 	flg_short_stay = (kind == STAY_INN_KIND_SHORT);
 	flg_mews = (kind == STAY_INN_KIND_MEWS);
 
@@ -2060,6 +2063,10 @@ void	stay_inn( stay_inn_kind_t kind )
 			continue;
 		}
 
+		/* פ */
+		update_playing_report_staying_inn_mbr(
+				mbr->ls_mbr_n, kind );
+
 		if( !flg_mews ){
 			/* ǤˤƤʤ HP  */
 			fx = srch_fx( &(mbr->fx), FX_KIND_POISON );
@@ -3320,6 +3327,28 @@ void	hear_rumor( shop_n_t shop_n )
 			MSG( rumor_tab[tab_n].n_msg_male ) );
 }
 
+/***************************************************************
+* ʧ
+* chr_t *chr : 饯
+* gold_t price : 
+***************************************************************/
+
+void	paying_gold( chr_t *chr, gold_t price )
+{
+	add_chr_gold( chr, -price );
+}
+
+/***************************************************************
+* λʧ
+* chr_t *chr : 饯
+* gold_t price : 
+***************************************************************/
+
+void	paid_gold( chr_t *chr, gold_t price )
+{
+	add_chr_gold( chr, +price );
+}
+
 /***************************************************************
 * 椫Ĵ٤
 * return : 椫?
